Jsw.namespace('Smb.AdminHome');

Smb.AdminHome.ApplicationItem = Class.create(Jsw.Component, {
    _tag: 'span',

    _initConfiguration: function($super, config) {
        $super(config);
        this._catalogId = this._getConfigParam('catalogId');
        this._data = this._getConfigParam('data');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            '<a href="#">' +
                '<span class="app-icon">' +
                    '<img alt="" src="' + this._data.icon.escapeHTML() + '"/>' +
                '</span>' +
                '<span class="app-name">' + this._data.title.escapeHTML() + '</span>' +
                '<span class="app-info">' + this._data.info.escapeHTML() + '</span>' +
            '</a>'
        );
    },

    _addEvents: function() {
        this._componentElement.down('a').observe('click', this._onClickEvent.bind(this));
    },

    _onClickEvent: function(event)
    {
        Event.stop(event);
        Jsw.redirectPost('/app/market/id/' + this._catalogId, { details: this._data.details });
    }
});

Smb.AdminHome.UpdateProgressNotification = Class.create(Jsw.Component, {

    STATUS_WORKING: 'working',
    STATUS_DONE: 'done',
    STATUS_NOTWORKING: 'notworking',

    updateInterval: 5,

    _initConfiguration: function($super, config) {

        $super(config);
        this._message = this._getConfigParam('message');
    },

    _addEvents: function() {
        this._processStatus({
            status: this.STATUS_WORKING,
            message: this._message
        });
    },

    _scheduleUpdateStatus: function() {
        this._statusUpdate.bind(this).delay(this.updateInterval);
    },

    _statusUpdate: function() {
        new Ajax.Request(Jsw.prepareUrl('/update/get-update-data'), {
            method: 'get',
            onSuccess: this._onSuccess.bind(this),
            onFailure: this._onFailure.bind(this)
        });
    },


    _onSuccess: function(transport) {
        try {
            this._processStatus(transport.responseText.evalJSON());
        } catch (e) {
            // Schedule new update - control panel is probably down
            this._scheduleUpdateStatus();
        }
    },


    _onFailure: function(transport) {

        // Schedule new update - control panel is probably down
        // or othewise unavailable due to updates installation.
        // Have no information to display.

        this._scheduleUpdateStatus();
    },


    _processStatus: function(response) {

        if (!response) {

            // Schedule new update - control panel is probably down
            this._scheduleUpdateStatus();
            
        } else if (this.STATUS_WORKING == response.status) {

            this._componentElement.update(
                '<div class="msg-box msg-warning msg-update-running">' +
                '<div><div><div><div><div>' +
                '<div class="msg-content">' +
                    this._message +
                '</div>' +
                '</div></div></div></div></div>' +
                '</div>'
            );

            this._scheduleUpdateStatus();

        } else if (this.STATUS_DONE == response.status || this.STATUS_NOTWORKING == response.status) {

            // Stop asynchronous notification and reload the whole page
            Jsw.redirect('/admin-home');
        }
    }

});

Smb.AdminHome.UpdateResultNotification = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._status = this._getConfigParam('status', 'info');
        this._message = this._getConfigParam('message', '');
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            '<div class="msg-box msg-' + this._status + '"><div><div><div><div><div>' +
            '<div class="msg-content">' + this._message + '</div></div></div></div></div></div></div>'
        );
    }

});

Smb.AdminHome.UpdateAvailableNotification = Class.create(Jsw.Component, {

    _initComponentElement: function($super) {
        $super();

        var id = this._getConfigParam('type');

        var buttonNow = this._getConfigParam('nowElement');
        var buttonElementNow = new Element('button', {
            type: 'submit'
        }).update(buttonNow.text);

        var linkLater = this._getConfigParam('laterElement');
        var linkElementLater = new Element('a', {
            href: '#'
        }).update('<span>' + linkLater.text + '</span>');

        var noteElement = new Element('div');
        noteElement.addClassName('msg-box');
        noteElement.addClassName('msg-update');

        noteElement.update(
            '<div><div><div><div><div>' +
            '<div class="msg-content">' +
              '<table class="update-container" cellspacing="0" width="100%">' +
                '<tbody>' +
                  '<tr>' +
                    '<td class="update">' +
                      '<span class="update-info">' + this._getConfigParam('message', '') + '</span>' +
                    '</td>' +
                    '<td class="update-links">' +
                    '<span id="control-' + id + '-now" class="btn"></span>' +
                    '<span id="control-' + id + '-later"></span>' +
                    '</td>' +
                  '</tr>' +
                '</tbody>' +
              '</table>' +
              '</div>' +
              '</div></div></div></div></div>');


        this._updateComponentElement(noteElement);
        $('control-' + id + '-now').insert(buttonElementNow);
        $('control-' + id + '-later').insert(linkElementLater);

        buttonElementNow.observe('click', function() {
            buttonNow.handler();
            return false;
        });

        linkElementLater.observe('click', function() {
            linkLater.handler();
            return false;
        });
    }
});

Smb.AdminHome.Panel = Class.create(Jsw.Panel, {

    render: function($super) {
        $super();
        this._renderHeader();
        this._renderLinks();
        this._renderAjaxPart();
        this._renderMoreLink();
    },

    _renderHeader: function() {
        var description = this._getConfigParam('description');
        if (!description) {
            return;
        }
        $(this._contentAreaId).insert({top: '<p>' + description + '</p>'});
    },

    _renderLinks: function() {
        var links = this._getConfigParam('links');
        if (!links) {
            return;
        }

        var list = new Element('ul');
        if (!$(this._contentAreaId + '-links')) {
            $(this._contentAreaId).insert('<div id="' + this._contentAreaId + '-links"></div>');
        }
        $(this._contentAreaId + '-links').update(list);
        links.each(function(unprocessedLink) {
            var linkElement = new Element('li');
            list.insert(linkElement);
            this._addLinkElement(linkElement, unprocessedLink);
        }, this);
    },

    _processLink: function(unprocessedLink) {
        return Object.clone(unprocessedLink);
    },

    _renderMoreLink: function() {
        var moreLink = this._getConfigParam('moreLink');
        if (!moreLink) {
            return;
        }

        unprocessedLink = Object.clone(moreLink);
        unprocessedLink.title = '<span>' + moreLink.title + ' <b>&gt;&gt;</b></span>'

        if (!$(this._contentAreaId + '-more')) {
            $(this._contentAreaId).insert('<span id="' + this._contentAreaId + '-more" class="more"></span>');
        }
        var parent = $(this._contentAreaId + '-more');
        parent.update('');
        this._addLinkElement(parent, unprocessedLink);
    },

    _addLinkElement: function(parent, unprocessedLink) {
        var link = this._processLink(unprocessedLink);
        if (link.disabled) {
            var linkElement = new Element('span')
                .update(link.title);
        } else {
            var linkElement = new Element('a', {
                href: Jsw.prepareUrl(link.href),
                target: link.target ? link.target : false
            }).update(link.title);
        }
        parent.insert(linkElement);
        if (link.description) {
            Jsw.Tooltip.init(linkElement, {text: link.description});
        }
        if (link.handler) {
            linkElement.observe('click', link.handler);
        }
    },

    _renderAjaxPart: function() {
        var url = this._getConfigParam('ajaxPartSource');
        if (!url) {
            return;
        }
        var categoriesElement = new Element('div')
            .update('<div class="ajax-loading">' +
                    this._getConfigParam('ajaxLoadingCaption') +
                    '</div>');
        $(this._contentAreaId).insert(categoriesElement);
        new Ajax.Updater(categoriesElement, Jsw.prepareUrl(url), {
            method: 'get',
            evalScripts: true,

            onComplete: function() {
                if (0 == categoriesElement.childElements().size()) {
                    categoriesElement.remove();
                }
            }
        });
    },

    _addTooltips: function() {
    }
});

Smb.AdminHome.WebSitesPanel = Class.create(Smb.AdminHome.Panel, {

    _initConfiguration: function($super, config) {
        $super(config);
        var domains = this._getConfigParam('domains', {});
        this._domains = Object.isArray(domains) ? $H({}) : $H(domains);
        this._domainId = this._getConfigParam('domainId');
        this._locale = this._getConfigParam('locale', {});
    },

    _initComponentElement: function($super) {
        $super();

        var list = new Element('div', {
            'class': "domains-list"
        });

        if (0 == this._domains.keys().length) {
            this._componentElement.addClassName('no-domain');
            list.insert(this._locale.noDomains);
        } else
        if (1 == this._domains.keys().length) {
            var domain = this._domains.values().first();
            this.domainSelectorElement = new Element('input', {
                type: 'hidden',
                name: 'domainId',
                value: domain.id
            });
            list.insert(domain.name.escapeHTML());
            list.insert(this.domainSelectorElement);
        } else {
            this.domainSelectorElement = new Element('select', {
                name: 'domainId'
            });
            this._domains.each(function(pair) {
                this.domainSelectorElement.insert(new Element('option', {
                    value: pair.key,
                    selected: pair.key == this._domainId ? 'selected' : false
                }).update(pair.value.name));
            }, this);
            list.insert(this.domainSelectorElement);
        }

        $(this._contentAreaId).insert(list);
    },

    _addEvents: function($super) {
        $super();
        if (!this.domainSelectorElement) {
            return;
        }

        this.domainSelectorElement.observe('change', this._onChangeDomain.bindAsEventListener(this));
    },

    _onChangeDomain: function(event) {
        this._domainId = this.domainSelectorElement ? this.domainSelectorElement.value : null;
        this._renderLinks();
        this._renderMoreLink();
    },

    _processLink: function($super, unprocessedLink) {

        var link = $super(unprocessedLink);

        if (link.href) {
            link.href = link.href.replace('%%domainId%%', this._domainId);
        }

        if (link.disabled || !link.requires) {
            return link;
        }
        var domain = $H(this._domains.get(this._domainId));
        if (!domain.get(link.requires.option)) {
            link.disabled = true;
            link.description = link.requires.description;
        }

        return link;
    }
});
