Jsw.namespace('Smb.Backup');
Smb.Backup.Progress = Class.create(Jsw.Component, {
    STATUS_WORKING: 'working',
    STATUS_SUCCESS: 'success',
    STATUS_WARNING: 'warning',
    STATUS_ERROR: 'error',
    STATUS_CANCELED: 'canceled',
    STATUS_NOT_EXIST: 'not_exist',

    updateInterval: 5,

    _initConfiguration: function($super, config) {
        $super(config);
        this._locale = this._getConfigParam('locale', {});
        this._downloadLogUrl = this._getConfigParam('downloadLogUrl', null);
        this._taskStatusUrl = this._getConfigParam('taskStatusUrl', null);
        this._taskCloseUrl = this._getConfigParam('taskCloseUrl', null);
    },

    _addEvents: function() {
        this._processStatus(this._getConfigParam('status', {}));
    },

    _sheduleUpdateStatus: function() {
        this._updateStatus.bind(this).delay(this.updateInterval);
    },

    _updateStatus: function() {
        new Ajax.Request(Jsw.prepareUrl(this._taskStatusUrl), {
          method: 'get',
          onSuccess: this._onSuccess.bind(this),
          onFailure: this._onFailure.bind(this)
        });
    },

    _onSuccess: function(transport) {
        var status = transport.responseText.evalJSON();
        this._processStatus(status);
    },

    _onFailure: function(transport) {
        var status = transport.responseText.evalJSON();
        this._processStatusFailure(status);
    },

    _processStatus: function(status) {
        if (!status.isBackup && !status.isRestore) {
            this._showNone(status);
        } else
        if (this.STATUS_WORKING != status.taskStatus) {
            this._showFinished(status);
        } else
        if (status.isBackup) {
            this._showBackup(status);
            this._sheduleUpdateStatus();
        } else
        if (status.isRestore) {
            this._showRestore(status);
            this._sheduleUpdateStatus();
        }
    },

    _processStatusFailure: function(transport) {
        this._sheduleUpdateStatus();
    },

    _showNone: function(status) {
        if (!this._componentElement) {
            return;
        }
        this._componentElement.remove();
    },

    _showFinished: function(status) {

        var createBackupButton = Jsw.getComponent('create-backup');
        if (createBackupButton) {
            createBackupButton.enable();
            createBackupButton.setTooltip(this._locale.hintButtonBackup);
        }
        var backupList = Jsw.getComponent('dumps-list');
        if (backupList) {
            backupList.reload();
        }

        var type = '';
        var links = ' <span class="task-status-link"><a id="closeLink" href="#">' + this._locale.closeTitle + '</a></span>';
        if (this.STATUS_SUCCESS == status.taskStatus || this.STATUS_CANCELED == status.taskStatus) {
            type = 'info';
        } else {
            if (this.STATUS_WARNING == status.taskStatus) {
                type = 'warning';
            } else {
                type = 'error';
            }
            var links = ' <span class="task-status-link"><a id="downloadLink" href="' + Jsw.prepareUrl(this._downloadLogUrl) + '">'
                + this._locale.downloadTitle + '</a></span>' + links;
        }

        var content = '<div class="msg-box msg-' + type + '"><div><div><div><div><div>' +
            '<div class="msg-content">' +
                '<span class="task-status-message">' + status.taskMessage + '</span>' + links +
            '</div></div></div></div></div></div></div>';

        this._componentElement.update(content);

        this._componentElement.select('#closeLink').each(function(element) {
            element.observe('click', this._onClose.bind(this, status));
        }, this);
    },

    _onClose: function(status) {
        if (!this._componentElement) {
            return;
        }
        this._componentElement.remove();
        new Ajax.Request(Jsw.prepareUrl(this._taskCloseUrl), {
            method: 'post',
            parameters: { 'close': true, 'id': status.taskId }
        });
    },

    _showBackup: function(status) {
        var content = '<div class="msg-box msg-progress">' +
            '<div><div><div><div><div>' +
                '<div class="msg-content">' +
                  '<table class="progress-container" cellspacing="0" width="100%"><tr>' +
                    '<td class="progress-info"><span>' + status.taskMessage + '</span> <span class="progress-start">' + status.creationDate + '</span></td>' +
                    '<td class="progress-indicator">' +
                      '<table cellspacing="0" width="100%"><tr>' +
                        '<td class="progress-status">' + this._locale.progressMessage + ': <span id="backupProgress">' + status.progress + '</span>%</td>' +
                        '<td>' +
                          '<span title="" class="gauge-wrapper f5 not_empty">' +
                            '<span class="gauge-container"><span id="backupProgressGauge" style="width: ' + status.progress + '%;" class="gauge-filled"></span></span>' +
                          '</span>' +
                        '</td>' +
                      '</tr></table>' +
                    '</td>' +
                  '</tr></table>' +
                '</div>' +
            '</div></div></div></div></div>' +
        '</div>';
        this._componentElement.update(content);
    },

    _showRestore: function(status) {
        var content = '<div class="msg-box msg-progress">' +
            '<div><div><div><div><div>' +
                '<div class="msg-content">' +
                  '<table class="progress-container" cellspacing="0" width="100%"><tr>' +
                    '<td class="progress-info"><span>' + status.taskMessage + ':</span> <span class="progress-current">' + status.dumpName + '</span></td>' +
                  '</tr></table>' +
                '</div>' +
            '</div></div></div></div></div>' +
        '</div>';

        this._componentElement.update(content);
    }

});