Jsw.namespace('Smb.Configure.Init');

Smb.Configure.Init.AjaxForm = Class.create(Jsw.FormSimple, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._locale = this._getConfigParam('locale', {});
        this._localeUrl = this._getConfigParam('localeUrl', null);
        this._element = this._getConfigParam('element', {});
    },

    _updateLocale: function(locale) {
        this._locale = locale;
        if (this._waitElement) {
            this._waitElement.remove();
            this._waitElement = null;
        }
        if (this._confirmElement) {
            this._confirmElement.remove();
            this._confirmElement = null;
        }
    },

    _addEvents: function($super) {
        $super();
        $('properties-localeCode').observe('change', this._onChangeLocale.bind(this));
    },

    _onChangeLocale: function() {
        if (!this._localeUrl) {
            return;
        }

        this.disable();

        var locale = $('properties-localeCode').value;
        var request = new Ajax.Request(
            this._localeUrl,
            {
                method:'post',
                parameters: {
                    locale: locale
                },
                onSuccess: this._onChangeLocaleSuccess.bind(this),
                onFailure: this._onFailure.bind(this)
            }
        );
    },

    _onChangeLocaleSuccess: function(req) {
        this._updateLocale(req.responseText.evalJSON());
        this.enable();
    },

    _processForm: function($super, response) {
        $super(response);
        if (this._hasErrors || this._hasFieldErrors) {
            this._getWaitElement().hide();
            this._componentElement.show();
            $(this._element['validation']).value = 'true';
            $(this._element['force']).value = 'false';
            return;
        }
        if (response.passwordConfirmationRequired) {
            this._getWaitElement().hide();
            this._processPasswordConfirmation();
            return;
        }
        if (response.redirect) {
            return;
        }
        if ('true' != $(this._element['validation']).value) {
            return;
        }
        this._configure();
    },

    _processPasswordConfirmation: function() {
        this._componentElement.hide();
        this._getConfirmElement().show();
    },

    _getWaitElement: function() {
        if (!this._waitElement) {
            this._waitElement = new Element('div', {
                'style': 'display: none;'
            }).update(
                '<div class="form-box">' +
                    '<div class="box-area">' +
                        '<div class="content">' +
                            '<div class="content-area">' +
                                '<div class="login-info">' +
                                    '<h3>' + this._locale.waitTitle + '</h3>' +
                                     this._locale.waitDescription +
                                '</div>' +
                            '</div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
                '<div class="btns-box">' +
                    '<div class="box-area">' +
                        '<div class="form-row">' +
                            '<div class="field-name">' +
                                '<span class="ajax-loading">' +
                                    this._locale.waitConfiguring +
                                '</span>' +
                            '</div>' +
                        '</div>' +
                    '</div>' +
                '</div>'
            );
            this._componentElement.insert({
                'after': this._waitElement
            });
        }
        return this._waitElement;
    },

    _getConfirmElement: function() {
        if (!this._confirmElement) {
            this._confirmElement = new Element('div', {
                'style': 'display: none;',
                'class': 'form-info'
            }).update(
                '<div class="form-box">' +
                    '<div class="box-area">' +
                        '<div class="content">' +
                            '<div class="content-area">' +
                                '<div class="login-info">' +
                                    this._locale.confirmDescription +
                                '</div>' +
                            '</div>' +
                        '</div>' +
                    '</div>' +
                '</div>' +
                '<div class="btns-box">' +
                    '<div class="box-area">' +
                        '<div class="form-row">' +
                            '<div class="field-value">' +
                                '<span class="btn action" id="btn-change"><button type="submit" value="" name="change">' +
                                    this._locale.buttonConfirmChangePassword +
                                '</button></span>' +
                                '<span class="btn" id="btn-force"><button type="button" value="" name="force">' +
                                    this._locale.buttonConfirmContinue +
                                '</button></span>' +
                            '</div>' +
                        '</div>' +
                    '</div>' +
                '</div>'
            );
            this._componentElement.insert({
                'after': this._confirmElement
            });
            $('btn-change').observe('click', this._onChangeClick.bind(this));
            $('btn-force').observe('click', this._onForceClick.bind(this));
        }
        this._confirmElement.down('.content-area')
            .insert({
                'top': '<div class="msg-box msg-warning"><div><div><div><div><div><div class="msg-content">' +
                    this._locale.confirmWarning +
                '</div></div></div></div></div></div></div>'
            });
        return this._confirmElement;
    },

    _onChangeClick: function() {
        this._getConfirmElement().hide();
        $(this._element['password']).value = '';
        $(this._element['passwordConfirmation']).value = '';
        this._componentElement.show();
    },

    _onForceClick: function() {
        $(this._element['force']).value = 'true';
        this._configure();
    },

    _configure: function() {
        this._componentElement.hide();
        this._getConfirmElement().hide();
        this._getWaitElement().show();
        $(this._element['validation']).value = 'false';
        this._onSubmit();
    }

});
