/* JavaScript Widgets */

Jsw = {

    version: '1.0',
    baseUrl: '',

    _registredComponents: null,
    _initOnReady: false,
    _firedOnReady: false,
    _onReadyEvents: null,

    registerComponent: function(identity, component) {
        if (!Jsw._registredComponents) {
            Jsw._registredComponents = new Hash();
        }

        Jsw._registredComponents.set(identity, component);
    },

    getComponent: function(identity) {
        return Jsw._registredComponents.get(identity);
    },

    clearStatusMessages: function() {
        var contentElement = $('content');

        ['.msg-error', '.msg-info', '.msg-warning'].each(function(msgClass) {
            contentElement.select(msgClass).each(function(messageElement) {
                messageElement.remove();
            });
        });
    },

    addStatusMessage: function(type, message) {
        try {
            $('main').insert({top: '<div class="msg-box msg-' + type + '"><div><div><div><div><div>' +
                '<div class="msg-content">' + message + '</div></div></div></div></div></div></div>'});
        } catch (e) {
            alert(type + ' | ' + message);
        }
    },

    onReady: function(callback) {
    	if (self._firedOnReady) {
    		callback();
    		return;
    	}
        if (!self._initOnReady) {
            Event.observe(window, 'load', Jsw._fireOnReady);
            self._initOnReady = true;
            self._onReadyEvents = new Array();
        }

        self._onReadyEvents.push(callback);
    },

    _fireOnReady: function() {
        self._onReadyEvents.each(function(callback) {
            callback();
        });

        self._firedOnReady = true;
    },

    namespace: function(ns) {
        var nsParts = ns.split('.');
        var root = window;

        for (var partIndex = 0; partIndex < nsParts.length; partIndex++) {
            if ('undefined' == typeof root[nsParts[partIndex]]) {
                root[nsParts[partIndex]] = {};
            }

            root = root[nsParts[partIndex]];
        }
    },

    prepareUrl: function(url) {
        if ('undefined' == typeof url || null === url) {
            return null;
        }

        if (!url.startsWith('/')) {
            return url;
        }

        return Jsw.baseUrl + url;
    }

};

Jsw.Component = Class.create({

    _tag: 'div',

    initialize: function(config) {
        this._initConfiguration(config);
        this._registerComponent();

        this._initComponentElement();

        if (this._autoRender && ((null != $(this._renderTargetId)) || (null != $(this._applyTargetId)))) {
            this.render();
        }
    },

    _initConfiguration: function(config) {
        this.initialConfig = config;
        this._config = this.initialConfig;

        this._cls = this._getConfigParam('cls', '');
        this._autoRender = this._getConfigParam('autoRender', true);
        this._renderTargetId = this._getConfigParam('renderTo', null);
        this._applyTargetId = this._getConfigParam('applyTo', null);

        this._id = (this._applyTargetId)
            ? this._applyTargetId
            : this._getConfigParam('id', null);

        if (null === this._id) {
            this._id = this._getRandomId();
            this._idIsRandom = true;
        }

        this._tag = (this._applyTargetId)
            ? $(this._applyTargetId).tagName
            : this._getConfigParam('tag', this._tag);
    },

    _registerComponent: function() {
        Jsw.registerComponent(this._id, this);
    },

    _initComponentElement: function() {
        if (this._applyTargetId) {
            this._componentElement = $(this._applyTargetId);
            return ;
        }

        this._componentElement = new Element(this._tag, {
            'id': this._id,
            'class': this._cls
        });
    },

    _initDisablerOverlay: function() {
        this._disablerOverlay = new Element('div');

        this._disablerOverlay.setStyle({
            display: 'none',
            zIndex: this._componentElement.style.zIndex + 1
        });

        this._disablerOverlay.addClassName('content-blocker');
        this._componentElement.appendChild(this._disablerOverlay);
    },

    addEventObserver: function(eventName, handler) {
        if ('undefined' != typeof handler) {
            this._componentElement.observe(eventName, handler);
        }
    },

    removeEventObserver: function(eventName, handler) {
        if ('undefined' != typeof handler) {
            this._componentElement.stopObserving(eventName, handler);
        }
    },

    _hasConfigParam: function(name)
    {
        return 'undefined' != typeof this._config[name];
    },

    _getConfigParam: function(name, defaultValue) {
        return this._hasConfigParam(name)
            ? this._config[name]
            : defaultValue;
    },

    _getRandomId: function() {
        var id = 'gen-id-' + this._getRandomNumber();

        while(null != $(id)) {
            id = 'gen-id-' + this._getRandomNumber();
        }

        return id;
    },

    _getRandomNumber: function() {
        return Math.floor(1000000*Math.random());
    },

    _addEvents: function() {
    },

    _addTooltips: function() {
        var description = this._getConfigParam('description');
        if  (description) {
            this._tooltip = Jsw.Tooltip.init(this._componentElement, {text: description});
        }
    },

    _updateComponentElement: function(content) {
        if (this._componentElement.empty()) {
            this._componentElement.update(content);
            return ;
        }

        var oldElements = this._componentElement.childElements();

        Element.insert(this._componentElement.firstChild, {before: content});

        oldElements.each(function(oldElement) {
            if (
                'undefined' == typeof oldElement.id ||
                '' == oldElement.id
            ) {
                return ;
            }

            var newElement = this._componentElement.select('#' + oldElement.id).first();

            if (newElement) {
                newElement.replace(oldElement);
            }
        }, this);
    },

    getId: function() {
        return this._id;
    },

    setRenderTarget: function(targetId) {
        this._renderTargetId = targetId;
    },

    getRenderTarget: function() {
        return this._renderTargetId;
    },

    show: function() {
        this._componentElement.show();
    },

    hide: function() {
        this._componentElement.hide();
    },

    render: function() {
        if ($(this._renderTargetId)) {
            var insertion = {};
            insertion[this._getConfigParam('renderMode', 'bottom')] = this._componentElement;
            $(this._renderTargetId).insert(insertion);
        }

        this._addEvents();
        this._addTooltips();
    }

});

Jsw.Hint = Class.create(Jsw.Component, {
    _tag: 'p',

    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = this._getConfigParam('cls', 'hint');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            this._getConfigParam('hint', '')
        );
    }
});

Jsw.Button = Class.create(Jsw.Component, {

    _tag: 'a',

    _initConfiguration: function($super, config) {
        $super(config);

        this._handler = this._getConfigParam('handler', false);
        if (Object.isString(this._handler)) {
            eval('this._handler = ' + this._handler);
        }
        this._cls = this._getConfigParam('cls', 'b-btn');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement.update(
            '<i><i><i><span>'
            + this._config['title']
            + '</span></i></i></i>'
        );

        this._initVisibility();
    },

    _initVisibility: function() {
        this._disabled = this._getConfigParam('disabled', false);

        if (this._disabled) {
            this._disabled = false;
            this.disable();
        } else {
            this._disabled = true;
            this.enable();
        }
    },

    _addAttribute: function(name, value) {
        if ('undefined' != typeof value) {
            this._componentElement.writeAttribute(name, value);
        }
    },

    setTooltip : function(tooltipText) {
        if (this._tooltip) {
            this._tooltip.setText(tooltipText);
        } else {
            this._tooltip = Jsw.Tooltip.init(this._componentElement, {text: tooltipText});
        }
    },

    enable: function() {
        if (!this._disabled) {
            return ;
        }
        this._disabled = false;

        var classNames = this._config['addCls'];
        if (!Object.isArray(classNames)) {
            classNames = [classNames];
        }
        classNames.each(function(item) {
            this._componentElement.addClassName(item);
        }, this);
        classNames.each(function(item) {
            this._componentElement.removeClassName(item + '-disabled');
        }, this);
        this._componentElement.removeClassName('btn-disabled');

        this._addAttribute('href', Jsw.prepareUrl(this._getConfigParam('href', '#')));
        this._addAttribute('target', this._getConfigParam('target', null));
        if (this._handler) {
            this.addEventObserver('click', this._handler);
        }
    },

    disable: function() {
        if (this._disabled) {
            return ;
        }
        this._disabled = true;

        this._componentElement.addClassName('btn-disabled');

        var classNames = this._config['addCls'];
        if (!Object.isArray(classNames)) {
            classNames = [classNames];
        }
        classNames.each(function(item) {
            this._componentElement.addClassName(item + '-disabled');
        }, this);
        classNames.each(function(item) {
            this._componentElement.removeClassName(item);
        }, this);
        this._componentElement.writeAttribute('href', null);
        this._componentElement.writeAttribute('target', null);
        if (this._handler) {
            this.removeEventObserver('click', this._handler);
        }
    }
});

Jsw.SmallButton = Class.create(Jsw.Button, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._cls = this._getConfigParam('cls', 's-btn');
    }

});

Jsw.BigButton = Class.create(Jsw.Button, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._icon = this._getConfigParam('icon', null);
    },

    _initComponentElement: function() {
        this._componentElement = new Element('a').insert(
            '<span class="db-content">' +
                '<span class="db-icon"><img src="' + this._icon + '"></span>' +
                '<span class="db-name">' + this._config['title'] + '</span>' +
                '<span class="db-info">' + this._config['description'] + '</span>' +
            '</span>'
        );

        this._initVisibility();
    }
});

Jsw.submit = function(element) {
    $(element).up("form").submit();
};

Jsw.redirect = function(action) {
    $(document).location.href = Jsw.prepareUrl(action);
};

Jsw.redirectPost = function(action, data, target) {
    Jsw.FormRedirect.redirect(action, 'post', data, target);
};

Jsw.FormRedirect = {
    redirect: function(action, method, data, target) {
        var form = new Element(
            'form',
            {
                method: method,
                action: Jsw.prepareUrl(action)
            }
        );
        if (target) {
            form.target = target;
        }
        if (data) {
            var elements = Jsw.FormRedirect.subToElements(data);
            $A(elements).each(function (element) {
                form.insert(element);
            });
        }
        $(document.body).insert(form);
        form.submit();
    },

    stringToElements: function(value, prefix)
    {
        return [new Element('input', {
            type: 'hidden',
            name: prefix,
            value: value
        })];
    },

    booleanToElements: function(value, prefix)
    {
        return [new Element('input', {
            type: 'hidden',
            name: prefix,
            value: value ? 1 : 0
        })];
    },

    arrayToElements: function(data, prefix)
    {
        var elements = [];
        $A(data).each(function(item) {
            elements = elements.concat(Jsw.FormRedirect.subToElements(item, '', prefix));
        });
        return elements;
    },

    hashToElements: function(data, prefix)
    {
        var elements = [];
        $H(data).each(function(pair) {
            elements = elements.concat(Jsw.FormRedirect.subToElements(pair.value, pair.key, prefix));
        });
        return elements;
    },

    subToElements: function(value, key, prefix)
    {
        var elements = [];
        var name = prefix
            ? prefix + '[' + key + ']'
            : key;
        if (Object.isString(value) || Object.isNumber(value)) {
            elements = elements.concat(Jsw.FormRedirect.stringToElements(value, name));
        } else
        if ('boolean' == typeof value) {
            elements = elements.concat(Jsw.FormRedirect.booleanToElements(value, name));
        } else
        if(Object.isArray(value)) {
            elements = elements.concat(Jsw.FormRedirect.arrayToElements(value, name));
        } else {
            elements = elements.concat(Jsw.FormRedirect.hashToElements(value, name));
        }
        return elements;
    }
}

Jsw.CommandButton = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._handler = this._getConfigParam('handler', false);
        if (Object.isString(this._handler)) {
            eval('this._handler = ' + this._handler);
        }
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            new Element('button', {
                type: 'button',
                value: this._config['value'],
                name: this._config['name']
            }).update(this._config['title'])
        );

        this._initVisibility();
    },

    _initVisibility: function() {
        this._disabled = this._getConfigParam('disabled', false);

        if (this._disabled) {
            this._disabled = false;
            this.disable();
        } else {
            this._disabled = true;
            this.enable();
        }
    },

    enable: function() {
        if (!this._disabled) {
            return ;
        }

        this._disabled = false;
        if ('send' == this._config['name']) {
            this._componentElement.addClassName('action');
        }
        this._componentElement.removeClassName('disabled');
        this._componentElement.disabled = false;
        if (this._handler) {
            this.addEventObserver('click', this._handler);
        }
    },

    disable: function() {
        if (this._disabled) {
            return ;
        }

        this._disabled = true;
        this._componentElement.disabled = true;
        if ('send' == this._config['name']) {
            this._componentElement.removeClassName('action');
        }
        this._componentElement.addClassName('disabled');
        if (this._handler) {
            this.removeEventObserver('click', this._handler);
        }
    }
});

Jsw.FormAjax = Class.create(Jsw.Component, {
    _sendButtonTitle: '',

    disable: function() {
        var sendButtonWrapper = $('btn-send');
        if (sendButtonWrapper) {
            var sendButton = sendButtonWrapper.down('button');
            sendButton.disabled = true;
            sendButtonWrapper.addClassName('disabled');
            if (!this._sendButtonTitle) {
                this._sendButtonTitle = sendButton.innerHTML;
            }
            sendButton.update('<span class="wait">' + this._config['waitButtonTitle'] + '</span>');
        }

        var cancelButtonWrapper = $('btn-cancel');
        if (cancelButtonWrapper) {
            cancelButtonWrapper.down('button').disabled = true;
            cancelButtonWrapper.addClassName('disabled');
        }
    },

    enable: function() {
        var sendButtonWrapper = $('btn-send');
        if (sendButtonWrapper) {
            sendButton = sendButtonWrapper.down('button');
            sendButton.disabled = false;
            sendButton.update(this._sendButtonTitle);
            sendButtonWrapper.removeClassName('disabled');
        }

        var cancelButtonWrapper = $('btn-cancel');
        if (cancelButtonWrapper) {
            cancelButtonWrapper.down('button').disabled = false;
            cancelButtonWrapper.removeClassName('disabled');
        }
    },

    _initComponentElement: function($super) {
        this._componentElement = $(this._id);
        this._initDisablerOverlay();

        var firstElement = this._componentElement.findFirstElement();

        if ('undefined' != typeof firstElement) {
            try {
                firstElement.focus();
            } catch (e) {}
        }

        this._submitInProgress = false;
    },

    _addEvents: function() {
        this._componentElement._formSubmit = this._componentElement.submit;
        this._componentElement.submit = this._onSubmit.bind(this);
        this._componentElement.observe('submit', this._onSubmitEvent.bind(this));
        this._addChoiceRadioButtonsOnClickEvent();
    },

    _addChoiceRadioButtonsOnClickEvent: function() {
        $$('input[type="radio"]').each(function(element) {
            if (!$(element.id).up('div.choice-block')) {
                return;
            }
            element.observe('click', function() {
                $(this.id).up('div.choice-block').select('span').each(function(element) {
                    element.removeClassName('selected');

                    if ('0' == $(this.id).value) {
                        element.removeClassName('no');
                    }
                }, this);

                $(this.id).up('span').addClassName('selected');

                if ('0' == $(this.id).value) {
                    $(this.id).up('span').addClassName('no');
                }
            });
        });
    },

    _onSubmitEvent: function(event) {
        this._onSubmit();
        Event.stop(event);
        return false;
    },

    _onSubmit: function() {
        if (this._submitInProgress) {
            return false;
        } else {
            this._submitInProgress = true;
        }

        this.disable();

        if (this._componentElement.enctype == "multipart/form-data") {
            this._componentElement._formSubmit();
            return true;
        }

        var actionUrl = this._componentElement.action;

        if (!actionUrl) {
            actionUrl = $(document).location.href;
        }

        // remove hash symbol (and the following) cause this will encoded and lead to problems
        actionUrl = actionUrl.replace(/#.*$/, "");

        var params = this._componentElement.serialize();
        var context = this;
        var request = new Ajax.Request(
            actionUrl,
            {
                method:'post',
                parameters: params,
                onSuccess: this._onSuccess.bind(this),
                onFailure: this._onFailure.bind(this)
            }
        );
    },

    _onFailure: function(req) {
        this._submitInProgress = false;
        Jsw.clearStatusMessages();
        this._clearMessages();
        this._addFormMessage('error', 'Internal error: ' + req.responseText);
        this.enable();
    },

    _onSuccess: function(req) {
        this._submitInProgress = false;
        Jsw.clearStatusMessages();
        try {
            var response = req.responseText.evalJSON();
            this._processForm(response);
        } catch (e) {
            this._clearMessages();
            this._addFormMessage('error', 'Internal error: ' + req.responseText);
            this.enable();
        }
    },

    _processForm: function(response) {
        this._processResponseRedirect(response.redirect);

        if (!response.redirect) {
            this._clearMessages();
            this._processResponseStatus(response.status);
            this._processResponseStatusMessages(response.statusMessages);
            this._processResponseFormMessages(response.formMessages);

            if (this._hasFieldErrors) {
                this._showFieldErrorArea();
            }
            this.enable();
        }
    },

    _showFieldErrorArea: function() {
        var errorsElements = this._componentElement.select('.field-errors');
        var firstError = null;

        errorsElements.each(function(errorElement) {
            if (errorElement.visible()) {
                firstError = errorElement;
            }
        });

        var hiddenContainerId = null;

        firstError.ancestors().each(function(element) {
            if (!element.visible()) {
                hiddenContainerId = element.id;
            }
        });

        if (!hiddenContainerId) {
            return ;
        }

        // in case of tabbed form we must switch to corresponding tab
        var tabsBar = Jsw.getComponent('tab-buttons-' + this._id);

        if (tabsBar) {
            tabsBar.switchTab(hiddenContainerId);
        }
    },

    _processResponseStatus: function (status) {
        if ('success' != status) {
            this._hasErrors = true;
        }
    },

    _clearMessages: function() {
        //clear field messages
        try {
            this._componentElement.select('.field-errors').each(function(errors){
                errors.hide();
                errors.up('.form-row').removeClassName('error');
                errors.select('.error-hint').each(function(error) {
                    error.remove();
                });
            });
        } catch (e) {
        }

        this._hasErrors = false;
        this._hasFieldErrors = false;
    },

    _processResponseStatusMessages: function (messages) {
        $A(messages).each(function(value) {
            this._addFormMessage(value.status, value.content);
        }, this);
    },

    _processResponseFormMessages: function (messages) {
        this._processFieldMessages(messages, []);
    },

    _addFieldMessage: function(errors, message) {
        errors.up('.form-row').addClassName('error');
        errors.insert({bottom: '<span class="error-hint">' + message + '</span>' });
        errors.show();
    },

    _processFieldMessage: function(prefix, name, message) {
        var fieldErrors = this._componentElement.down('#' + prefix.join('-')).up('.form-row').down('.field-errors');
        this._addFieldMessage(fieldErrors, message);
        this._hasFieldErrors = true;
    },

    _processFieldMessages: function(messages, prefix) {
        if (Object.isArray(messages)) {
            $A(messages).each(function(message) {
                if (Object.isString(message)) {
                    this._processFieldMessage(prefix, 'error', message);
                } else {
                    prefix.push(name);
                    this._processFieldMessages(message, prefix);
                    prefix.pop();
                }
            }, this);
        } else {
            $H(messages).each(function(pair) {
                if (Object.isString(pair.value)) {
                    this._processFieldMessage(prefix, pair.key, pair.value);
                } else {
                    prefix.push(pair.key);
                    this._processFieldMessages(pair.value, prefix);
                    prefix.pop();
                }
            }, this);
        }
    },

    _addFormMessage: function (type, message) {
        Jsw.addStatusMessage(type, message);
    },

    _processResponseRedirect: function (redirect) {
        if (redirect) {
            Jsw.redirect(redirect);
        }
    }

});

Jsw.FormSimple = Class.create(Jsw.FormAjax, {
    _processResponseFormMessages: function (messages) {
        this._messages = '';
        this._processFieldMessages(messages, []);
        if (this._messages) {
            this._addFormMessage('error', this._messages);
        }
    },

    _processFieldMessage: function(prefix, name, message) {
        if (!this._hasErrors) {
            try {
                this._componentElement.down('#' + prefix.join('-')).focus()
            } catch (e) {}
        }
        this._hasErrors = true;
        this._messages += message + '<br/>';
    },

    _addFormMessage: function (type, message) {
        try {
            this._componentElement.down('.content-area').insert({top: '<div class=\"msg-box msg-' + type +
                '\"><div><div><div><div><div><div class=\"msg-content\">' + message + '</div></div></div></div></div></div></div>'});
        } catch (e) {
            alert(type + ' | ' + message);
        }
    }
});

Jsw.Container = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._contentAreaId = this._id;

        this._initItems();
    },

    _initItems: function() {
        this._items = this._getConfigParam('items', null);

        if (null != this._items) {
            this._items.each(function(item, index) {
                if ('undefined' != typeof item.componentType) {
                    // recreate proper object defined by componentType
                    eval('var resultItem = new ' + item.componentType + '(item);');
                    this._items[index] = resultItem;
                }
            }, this);
        }
    },

    _renderItems: function() {
        if (null != this._items) {
            this._items.each(function(item) {
                this._renderItem(item);
            }, this);
        }
    },

    _renderItem: function(item) {
        item.setRenderTarget(this._contentAreaId);
        item.render();
    },

    render: function($super) {
        $super();

        this._renderItems();
    },

    getItems: function() {
        return this._items;
    }

});

Jsw.ListContainer = Class.create(Jsw.Container, {

    _tag: 'ul',

    _renderItem: function(item) {
        var renderTargetId = this._id + '-item-' + item.getId();
        var cls = '';
        if (this._getConfigParam('renderLastItemClass', false) && this._items.last() == item) {
            cls = ' class="last"';
        }
        $(this._contentAreaId).insert('<li id="' + renderTargetId +'"' + cls + '></li>');
        item.setRenderTarget(renderTargetId);
        item.render();
    }

});

Jsw.Dashboard = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._buttonsAreaId =this._id + '-buttons-area';
    },

    _initComponentElement: function() {
        this._componentElement = new Element('div', {
                'class': this._cls
            }).update(
                '<ul id="' + this._buttonsAreaId + '" class="d-buttons">' +
                    this._getConfigParam('html', '') +
                '</ul>'
            );
    },

    _renderItem: function(item) {
        var renderTargetId = this._id + '-button-' + item.getId();
        $(this._buttonsAreaId).insert('<li id="' + renderTargetId +'"></li>');
        item.setRenderTarget(renderTargetId);
        item.render();
    }

});

Jsw.Panel = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._titleAreaId = this._id + '-title-area';
        this._contentAreaId = this._id + '-content-area';
        this._boxItemsAreaId = this._id + '-box-area';
        this._initBoxItems();
    },

    _initBoxItems: function() {
        this._boxItems = this._getConfigParam('boxItems', null);

        if (null != this._boxItems) {
            this._boxItems.each(function(item, index) {
                if ('undefined' != typeof item.componentType) {
                    // recreate proper object defined by componentType
                    eval('var resultItem = new ' + item.componentType + '(item);');
                    this._boxItems[index] = resultItem;
                }
            }, this);
        }
    },

    _initComponentElement: function($super) {
        $super();

        var title = this._getConfigParam('title', '')
            ?   '<div class="title">' +
                    '<div class="title-area" id="' + this._titleAreaId + '">' +
                        '<h3><span>' + this._getConfigParam('title', '') + '</span></h3>' +
                    '</div>' +
                '</div>'
            : '';

        this._updateComponentElement(
            '<div class="box-area">' +
                title +
                '<div id="' + this._boxItemsAreaId + '"></div>' +
                '<div class="content">' +
                    '<div class="content-area">' +
                        '<div class="content-wrapper" id="' + this._contentAreaId + '">' +
                            this._getConfigParam('html', '') +
                        '</div>' +
                    '</div>' +
                '</div>' +
            '</div>'
        );
    },

    render: function($super) {
        $super();

        this._renderBoxItems();
    },

    _renderBoxItems: function() {
        if (null != this._boxItems) {
            this._boxItems.each(function(item) {
                this._renderBoxItem(item);
            }, this);
        }
    },

    _renderBoxItem: function(item) {
        item.setRenderTarget(this._boxItemsAreaId);
        item.render();
    },

    _isHidden: function()
    {
        var rememberedStatus = Jsw.Cookie.get(this._id + '-hidden');
        if (this._idIsRandom || null === rememberedStatus) {
            return this._getConfigParam('hidden', false);
        }
        return 1 == rememberedStatus;
    },

    _setHidden: function(hidden)
    {
        if (this._getConfigParam('hidden', false) == hidden) {
            Jsw.Cookie.remove(this._id + '-hidden');
        } else {
            Jsw.Cookie.set(this._id + '-hidden', hidden ? 1 : 0);
        }
    },

    _addEvents: function($super) {
        $super();
        if (this._isHidden()) {
            this.hideContent();
        } else {
            this.showContent();
        }
        this._componentElement.select('#' + this._titleAreaId).each(function(titleAreaElement) {
            Event.observe(titleAreaElement, 'click', this.toggleContent.bindAsEventListener(this));
        }, this);
    },

    showContent: function() {
        this._componentElement.removeClassName('hide');
        if (!this._idIsRandom)
            this._setHidden(false);
    },

    hideContent: function() {
        this._componentElement.addClassName('hide');
        if (!this._idIsRandom)
            this._setHidden(true);
    },

    toggleContent: function() {
        this._componentElement.hasClassName('hide')
            ? this.showContent()
            : this.hideContent();
    }

});

Jsw.CollapsibleBlock = Class.create(Jsw.Container, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._blockAreaId = this._id + '-block';
        this._titleAreaId = this._id + '-title-area';
        this._contentAreaId = this._id + '-content-area';
    },

    _initComponentElement: function($super) {
        $super();

        var containerContentChilds = this._componentElement.childElements();

        this._updateComponentElement(
            '<div class="' + this._cls +  '-block' + (this._getConfigParam('collapsed', true) ? ' hide' : '') + '" id="' + this._blockAreaId + '">' +
                '<div class="' + this._cls +  '-title" id="' + this._titleAreaId + '">' +
                    '<span>' + this._getConfigParam('title', '') +  '</span>' +
                '</div>' +
                '<div class="' + this._cls +  '-content" id="' + this._contentAreaId + '"></div>' +
            '</div>'
        );
    },

    _addEvents: function($super) {
        $super();
        $(this._titleAreaId).down('span').observe('click', this._onTitleClickEvent.bind(this));
    },

    _onTitleClickEvent: function(event) {
        Event.stop(event);
        $(this._blockAreaId).toggleClassName('hide');
    }
});

Jsw.Collapsible = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._contentAreaId = this._id + '-content-area';
    },

    _initComponentElement: function($super) {
        $super();

        var containerContentChilds = this._componentElement.childElements();

        this._updateComponentElement(
            '<div class="collapsible-box collapsed">' +
                '<div class="collapsible-anchor"></div>' +
                '<div class="collapsible-area">' +
                    '<div class="tl"><div class="br"><div class="bl"><div class="tr">' +
                        '<div class="collapsible-content" id="' + this._contentAreaId + '">' +
                            this._getConfigParam('html', '') +
                            //...collapsible elements
                        '</div>' +
                    '</div></div></div></div>' +
                '</div>' +
             '</div>'
        );
    },

    _addEvents: function($super) {
        $super();

        //init collapsed status
        if (this._getConfigParam('collapsed', true)) {
            this.collapse();
        } else {
            this.expand();
        }
        //handle click event on anchor
        this._componentElement.select('.collapsible-anchor').each(function(anchorElement) {
            Event.observe(anchorElement, 'click', this._onAnchorClickEvent.bind(this));
        }, this);
    },

    _onAnchorClickEvent: function(event) {
        if (this._collapsed) {
            this.expand();
        } else {
            this.collapse();
        }
        Event.stop(event);
    },

    _getCollapseBinding: function() {
        if (!this._collapseBinding) {
            this._collapseBinding = this.collapse.bind(this);
        }
        return this._collapseBinding;
    },

    collapse: function() {
        if (this._collapsed) {
            return;
        }
        this._collapsed = true;
        Event.stopObserving(document, 'click', this._getCollapseBinding());
        var content = $(this._contentAreaId).up('.collapsible-box');
        content.removeClassName('expanded');
        content.addClassName('collapsed');
    },

    expand: function() {
        if (!this._collapsed) {
            return;
        }
        this._collapsed = false;
        var content = $(this._contentAreaId).up('.collapsible-box');
        content.removeClassName('collapsed');
        content.addClassName('expanded');
        Event.observe(document, 'click', this._getCollapseBinding());
    }

});

Jsw.Dropdown = Class.create(Jsw.Collapsible, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._valuesAreaId = this._id + '-values-area';
        this.onChange = this._getConfigParam('onChange', this.onChange);
    },

    _initComponentElement: function($super) {
        $super();
        this._componentElement.down('#' + this._contentAreaId).update(
            '<h4><span>' + this._getConfigParam('title', '') + '</span></h4>' +
            '<ul id="' + this._valuesAreaId + '"></ul>'
        );
    },

    _renderItem: function(item) {
        var dropdownItem = new Jsw.DropdownItem(item);

        var valueItem = new Element('a').update(dropdownItem.title.escapeHTML());

        $(this._valuesAreaId).insert(
            new Element('li').update(valueItem)
        );

        valueItem.observe('click', this._onClick.bindAsEventListener(this, dropdownItem));
    },

    _onClick: function(event, item)
    {
        this.onChange(item);
    },

    onChange: function(item) {
        this.setValue(item.value);
    },

    setValue: function(value) {
        this._value = value;
    },

    getValue: function() {
        return this._value;
    }

});

Jsw.DropdownItem = Class.create({

    initialize: function(item) {
        if (Object.isString(item)) {
            this.value = item;
            this.title = item;
        } else
        if (item.title || item.value) {
            this.value = item.value;
            this.title = item.title;
        }
    }
});

Jsw.Pathbar = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._contentAreaId = this._id + '-content-area';
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            '<ul id="' + this._contentAreaId + '">' +
            '</ul>'
        );
    },

    _renderItem: function(item) {
        var renderTargetId = this._id + '-item-' + item.getId();
        $(this._contentAreaId).insert('<li id="' + renderTargetId +'"></li>');
        item.setRenderTarget(renderTargetId);
        item.render();
        this._renderItemSuffix(item);
    },

    _renderItemSuffix: function(item) {
        var renderTargetId = this._id + '-item-' + item.getId();
        $(renderTargetId).insert("<b>&gt;</b>");
    }

});

Jsw.Pathbar.Item = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._title = this._getConfigParam('title', '');
        this._href = this._getConfigParam('href', '');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement = new Element('a', {
            'href': this._href
        }).update('<span>' + this._title + '</span>');
    },

    getHref: function() {
        return this._href;
    }
});

Jsw.Pathbar.SimpleItem = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._title = this._getConfigParam('title', '');
    },

    _initComponentElement: function($super) {
        $super();

        this._componentElement = new Element('span');
        this._componentElement.update(this._title);
    }
});


Jsw.Bar = Class.create(Jsw.Container, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._contentAreaId = this._id + '-content-area';

        // allowed types: static, dynamic
        this._type = this._getConfigParam('type', 'static');
    },

    _initComponentElement: function($super) {
        $super();

        var content = '<ul id="' + this._contentAreaId + '"></ul>';
        if ('navbar' != this._id) {
            content = '<div class="tabs-area">' + content + '</div>';
        }

        this._updateComponentElement(content);
    },

    _renderItems: function() {
        if (null != this._items) {
            var size = this._items.size();
            this._items.each(function(item, i) {
                this._renderItem(item, i, size);
            }, this);
        }
    },

    _renderItem: function(item, i, size) {
        if (0 == i && 'navbar' != this._id) {
            var renderTargetId = 'first-tab';
        } else if (size - 1 == i && 'navbar' != this._id) {
            var renderTargetId = 'last-tab';
        } else {
            var renderTargetId = this._id + '-item-' + item.getId();
        }
        var containerCls = item.getContainerClass();

        $(this._contentAreaId).insert('<li class="' + containerCls + '" id="' + renderTargetId +"\"></li>");
        item.setRenderTarget(renderTargetId);
        item.render();

        if ('dynamic' == this._type) {
            item.addEventObserver('click', item.switchTab.bindAsEventListener(item));
        }

        if (!$('main').hasClassName('tabed') && 'navbar' != this._id) {
            $('main').addClassName('tabed');
        }
    }
});

Jsw.bar = {};

Jsw.bar.Tabs = Class.create(Jsw.Bar, {

    switchTab: function(tabId) {
        var activeTab = null;

        this.getItems().each(function(item) {
            if (tabId == item.getTabId()) {
                activeTab = item;
            }

            $(item.getTabId()).hide();
            $(item.getRenderTarget()).removeClassName('active');
        });

        $(tabId).show();
        $(activeTab.getRenderTarget()).addClassName('active');
    }
});

Jsw.bar.Button = Class.create(Jsw.Button, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._cls = this._getConfigParam('cls', '');
        this._containerCls = this._getConfigParam('containerCls', '');
        this._tabId = this._getConfigParam('tabId', null);
        this.navigationTab = this._getConfigParam('navigationTab', false);
    },

    _initComponentElement: function() {
        this._componentElement = new Element('a', {
            'class': this._cls
        }).update('<span>' + this._config['title'] + '</span>');

        this._initVisibility();
    },

    getContainerClass: function() {
        return this._containerCls;
    },

    getTabId: function() {
        return this._tabId;
    },

    switchTab: function(event) {
        var bar = Jsw.getComponent(Event.element(event).up('ul').up('div').up('div').id);
        bar.switchTab(this._tabId);
    }

});

Jsw.list = {

    COLUMN_SELECTION: {
        cls: 'select',
        headerCls: 'select',
        headerRenderer: function(column) {
            return '<input type="checkbox" class="checkbox" name="listGlobalCheckbox"/>';
        },
        renderer: function(item, isDisabled) {
            if (!isDisabled) {
                return '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="' + item.id + '"/>';
            }

            var html =
                '<div>' +
                    '<span class="checkbox-disabled-wrapper"></span>' +
                    '<input style="z-index: 1;" disabled="disabled" type="checkbox" class="checkbox"/>' +
                '</div>';

            return html;
        }
    }

};

Jsw.List = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._listCls = this._getConfigParam('listCls', 'list');
        this._tableId = this._id + '-table';
        this._dataUrl = this._getConfigParam('dataUrl', '');
        this._operations = this._getConfigParam('operations', null);
        this._operationsClass = this._getConfigParam('operationsClass', 'list-actions');
        this._operationsTag = this._getConfigParam('operationsTag', 'span');
        this._actionsClass = this._getConfigParam('actionsClass', 'action-btns-block');
        this._columns = this._getConfigParam('columns', null);
        this._limitValues = this._getConfigParam('limitValues', [10, 25, 100]);
        this._splitListData(this._getConfigParam('data', { data: null, pathbar: null, state: null, pager: null, locale: null }));
        this._rowSelectable = this._isColumnSelectionPresent();
        this._typeFilter = this._getConfigParam('typeFilter', null);
        this._searchable = this._getConfigParam('searchable', true);
        this._pageable = this._getConfigParam('pageable', true);
        this._alwaysShowSearch = this._getConfigParam('alwaysShowSearch', false);
        this._disabledSelectHint = this._getConfigParam('disabledSelectHint', '');

        this.isDisabledItem = this._getConfigParam('isDisabledItem', function() {
            return false;
        });
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement('<div id="' + this._id + '-container"></div>');
        this._initDisablerOverlay();
    },

    _splitListData: function(listData) {
        if (!listData) {
            return false;
        }

        if (!listData.data || !listData.state || !listData.pager || !listData.locale) {
            return false;
        }
        this._data = listData.data;
        this._state = listData.state;
        this._pager = listData.pager;
        this._locale = listData.locale;

        if (listData.pathbar) {
            this._pathbar = listData.pathbar;
        }
        return true;
    },

    _isColumnSelectionPresent: function() {
        for (var index = 0; index < this._columns.length; index++) {
            if (Jsw.list.COLUMN_SELECTION == this._columns[index]) {
                return true;
            }
        }

        return false;
    },

    onHeaderClick: function(dataIndex) {
        this._state.sortField = dataIndex;
        this._state.sortDirection = ('down' == this._state.sortDirection)
            ? 'up'
            : 'down';

        this.reload('/sort-field/' + dataIndex + '/sort-dir/' + this._state.sortDirection);
    },

    onLimitClick: function(value) {
        this.reload('/items-per-page/' + value);
    },

    onPagerClick: function(page) {
        this.reload('/page/' + page);
    },

    onTypeFilterChange: function(typeFilter) {
        this.reload('/type-filter/' + typeFilter);
    },

    _getListHeadersHtml: function() {
        var html = '<tr>';
        var colspan = 0;

        this._columns.each(function(column) {
            if (colspan) {
                colspan --;
                return;
            }

            if (column.headerColspan) {
                colspan = column.headerColspan;
            }

            var data = '';

            var headerCls = '';

            if ('undefined' != typeof column.headerCls) {
                headerCls = column.headerCls;
            }

            if ('undefined' != typeof column.headerRenderer) {
                data = column.headerRenderer(column);
            } else {
                data = column.header;

                var sortCssClass = '';

                if (this._state.sortField == column.dataIndex) {
                    sortCssClass = ('down' == this._state.sortDirection)
                        ? ''
                        : 'sort-up';

                    headerCls = (headerCls)
                        ? (headerCls + ' ' + 'sort')
                        : 'sort';
                }

                if (column.sortable) {
                    data = '<a class="' + sortCssClass + '" href="#" onclick="Jsw.getComponent(\'' + this._id
                        + '\').onHeaderClick(\'' + column.dataIndex + '\')">' + data + '</a>';
                }
            }

            html += '<th class="' + headerCls + '"' + (colspan ? 'colspan="' + colspan + '"' : '') + '>' + data + '</th>';
        }, this);

        html += '</tr>';

        return html;
    },

    _getListDataHtml: function() {
        if (!this._data) {
            return ;
        }

        var html = '';
        var currentRowClass = 'odd';

        this._data.each(function(item) {
            html += '<tr class="' + currentRowClass + '">';

            this._columns.each(function(column) {
                var data = '';

                if ('undefined' != typeof column.renderer) {
                    var isDisabled = this.isDisabledItem(item);
                    data = column.renderer(item, isDisabled);
                } else if ('undefined' != typeof column.dataIndex) {
                    data = item[column.dataIndex].escapeHTML();
                }

                var itemCls = '';

                if ('undefined' != typeof column.cls) {
                    itemCls = column.cls;
                }

                html += '<td class="' + itemCls + '">' + data + '</td>';
            }, this);

            html += '</tr>';

            currentRowClass = ('odd' == currentRowClass) ? 'even' : 'odd';
        }, this);

        return html;
    },

    _getListHtml: function() {
        if (0 == this._pager.totalItemCount) {
            return '<span class="empty-list">' + this._locale.noEntriesFound + '</span>';
        }

        var html =
            this._getPagerHtml() +
            '<div class="' + this._listCls + '">' +
                '<table width="100%" cellspacing="0" id="' + this._tableId + '">' +
                    this._getListHeadersHtml() +
                    this._getListDataHtml() +
                '</table>' +
            '</div>' +
            this._getPagerHtml();

        return html;
    },

    _getPathbarHtml: function() {
        if (!this._pathbar) {
            return '';
        }

        return '<div id="' + this._id + '-pathbar"></div>';
    },

    _getPagerHtml: function() {
        if (!this._pageable) {
            return '';
        }
        var totalRecords = this._locale.recordsTotal.replace('%%total%%', this._pager.totalItemCount);

        var html =
            '<div class="paging">' +
                '<div class="paging-area">' +
                    '<span class="paging-info">' + totalRecords + '</span>' +
                    '<span class="paging-view">' + this._locale.numberOfItemPerPage + ': ' +
                        this._getLimitValuesHtml() +
                    '</span>';

        if (this._pager.pageCount > 1) {
            html += '<span class="paging-nav">' + this._locale.pages + ': ' + this._getPagesItemsHtml() + '</span>';
        }

        html += '</div></div>';

        return html;
    },

    _getLimitValuesHtml: function() {
        var html = '';

        this._limitValues.each(function(limitValue) {
            if (this._pager.itemCountPerPage != limitValue) {
                html += '<a href="#" onclick="Jsw.getComponent(\'' + this._id +
                    '\').onLimitClick(' + limitValue + ');">' + limitValue + '</a> ';
            } else {
                html += '<span>' + limitValue + '</span> ';
            }
        }, this);

        return html;
    },

    _getPagesItemsHtml: function() {
        var html = '';

        if (this._pager.first != this._pager.current) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.first) + '">'
                + this._locale.firstPage + '</a> ';
        } else {
            html += '<span>' + this._locale.firstPage + '</span> ';
        }

        if (this._pager.previous) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.previous) + '">&lt;&lt;</a> ';
        } else {
            html += '<span>&lt;&lt;</span> ';
        }

        $H(this._pager.pagesInRange).values().each(function(page) {
            if (page != this._pager.current) {
                html += '<a href="#" onclick="' + this._getPageItemLink(page) + '">' + page + '</a> ';
            } else {
                html += page + ' ';
            }
        }, this);

        if (this._pager.next) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.next) + '">&gt;&gt;</a> ';
        } else {
            html += '<span>&gt;&gt;</span> ';
        }

        if (this._pager.last != this._pager.current) {
            html += '<a href="#" onclick="' + this._getPageItemLink(this._pager.last) + '">'
                + this._locale.lastPage + '</a> ';
        } else {
            html += '<span>' + this._locale.lastPage + '</span> ';
        }

        return html;
    },

    _getPageItemLink: function(page) {
        return "Jsw.getComponent('" + this._id + "').onPagerClick(" + page + ");";
    },

    _getActionsBoxHtml: function() {
        if (!this._searchable && null == this._operations) {
            return '';
        }

        var searchStateClass = '';

        if (this._state.forceShowSearch) {
            Jsw.Cookie.set(this._id + '-search-show', 'true');
        }

        if (
            this._searchable &&
            !this._alwaysShowSearch &&
            'true' != Jsw.Cookie.get(this._id + '-search-show')
        ) {
            searchStateClass = ' hide';
        }

        var html = '<div class="actions-box' + searchStateClass + '">';


        if (this._searchable) {
            html +=
                '<div class="search-box">' +
                    '<ul>' +
                        this._getSearchFieldsHtml() +
                        this._getTypeFilterHtml() +
                    '</ul>' +

                    '<a class="s-btn sb-search" href="#">' +
                        '<i><span>' + this._locale.buttonSearch + '</span></i>' +
                    '</a>' +
                    '<a class="s-btn sb-show-all" href="#">' +
                        '<i><span>' + this._locale.buttonResetSearch + '</span></i>' +
                    '</a>' +
                '</div>';
        }

        html +=
                '<div id="' + this._id + '-actions-box" class="' + this._actionsClass + '">' +
                    '<div class="action-btns-area">';

        if (this._searchable && !this._alwaysShowSearch) {
            html +=
                        '<span class="search-control">' +
                            '<a class="s-btn sb-search-show" href="#">' +
                                '<i><span>' + this._locale.showSearch + '</span></i>' +
                            '</a>' +
                            '<a class="s-btn sb-search-hide" href="#">' +
                                '<i><span>' + this._locale.hideSearch + '</span></i>' +
                            '</a>' +
                        '</span>';
        }

        html +=
                        '<' + this._operationsTag + ' id="' + this._id +
                            '-operations" class="' + this._operationsClass + '">' +
                        '</' + this._operationsTag + '>' +
                    '</div>' +
                '</div>' +
            '</div>';

        return html;
    },

    _getSearchFieldsHtml: function() {
        if (!this._state.searchFields) {
            return '';
        }

        var searchFieldsHtml = '';

        $H(this._state.searchFields).each(function(searchField) {
            var searchFieldName = searchField[0];
            var searchFieldTitle = $H(searchField[1]).get('title');

            var searchFieldTitleHtml = '';

            if ('undefined' != typeof searchFieldTitle) {
                searchFieldTitleHtml = '<span>' + searchFieldTitle + '</span>';
            }

            searchFieldsHtml +=
                '<li>' +
                    '<div>' +
                        searchFieldTitleHtml +
                        '<input id="' + this._id + '-search-text-' + searchFieldName + '" type="text" value="' +
                            $H(this._state.searchTexts).get(searchFieldName).escapeHTML() + '"/>' +
                    '</div>' +
                '</li>';
        }, this);

        return searchFieldsHtml;
    },

    _getTypeFilterHtml: function() {
        if (!this._typeFilter) {
            return '';
        }

        var optionsHtml = '';

        var optionsHash = $H(this._state.typeFilterOptions);

        if (Object.isArray(this._state.typeFilterOptions)) {
            optionsHash = $H();
            $A(this._state.typeFilterOptions).each(function(value, index) {
                optionsHash.set(index, value);
            });
        }

        optionsHash.each(function(option) {
            var selected = (this._state.typeFilter == option[0])
                ? 'selected="selected"'
                : '';
            optionsHtml += '<option value="' + option[0] + '"' + selected + '>' + option[1].escapeHTML() + '</option>';
        }, this);

        var typeFilterHtml =
            '<li>' +
                '<div>' +
                    '<span>' + this._typeFilter.title + '</span>' +
                    '<select id="' + this._id + '-type-filter" onchange="Jsw.getComponent(\'' + this._id
                        + '\').onTypeFilterChange(this.value)">' + optionsHtml + '</select>' +
                '</div>' +
            '</li>';

        return typeFilterHtml;
    },

    _addSearchHandlers: function() {
        if (!this._searchable) {
            return;
        }

        var context = this;

        this._componentElement.select('.search-control .s-btn').each(function(element) {
            element.observe('click', function() {
                Jsw.Cookie.set(context._id + '-search-show', this.up('.actions-box').hasClassName('hide'));
                this.up('.actions-box').toggleClassName('hide');
                context._hideItemsNotSelectedWarning();
                return false;
            });
        });

        var searchLink = this._componentElement.select('.sb-search').first();
        searchLink.observe('click', function() {
            var searchQuery = '';
            var isEmptySearch = false;

            $H(context._state.searchFields).each(function(searchField) {
                var searchFieldName = searchField[0];
                var searchFieldValue = $(context._id + '-search-text-' + searchFieldName).value.strip();

                searchQuery += ((searchQuery) ? '&' : '?')
                    + 'search-text-' + searchFieldName + '=' + searchFieldValue;
            });

            if (isEmptySearch) {
                context.reload('/reset-search/true/');
            } else {
                context.reload(searchQuery);
            }
        });

        var resetSearchLink = this._componentElement.select('.sb-show-all').first();
        resetSearchLink.observe('click', function() {
            context.reload('/reset-search/true/');
        });
    },

    _addSelectionHandlers: function() {
        var context = this;

        var globalCheckbox = this._componentElement.select('input[name="listGlobalCheckbox"]').first();

        globalCheckbox.observe('click', function() {
            context._componentElement.select('input[name="listCheckbox[]"]').each(function(checkbox) {
                if (globalCheckbox.checked) {
                    checkbox.up('tr').addClassName('selected');
                } else {
                    checkbox.up('tr').removeClassName('selected');
                }
                checkbox.checked = globalCheckbox.checked;
            });
        });

        this._componentElement.select('input[name="listCheckbox[]"]').each(function(checkbox) {
            checkbox.observe('click', function() {
                if (checkbox.checked) {
                    checkbox.up('tr').addClassName('selected');
                } else {
                    checkbox.up('tr').removeClassName('selected');
                    globalCheckbox.checked = false;
                }
            });
        });
    },

    _addOperations: function() {
        this._operations.each(function(config) {
            eval('var operation = new ' + config.componentType + '(config);');
            operation.setRenderTarget(this._id + '-operations');
            operation.render();
        }, this);
    },

    _addPathbar: function() {
        if (!this._pathbar) {
            return;
        }

        eval('this._pathbarComponent = new ' + this._pathbar.componentType + '(this._pathbar);');
        this._pathbarComponent.setRenderTarget(this._id + '-pathbar');
        this._pathbarComponent.render();
    },

    disable: function() {
        this._disablerOverlay.show();
        this._disablerOverlay.clonePosition(this._componentElement);
    },

    enable: function() {
        this._disablerOverlay.hide();
    },

    getSelectedItemsIds: function() {
        var itemsIds = new Array();

        this._componentElement.select('input[name="listCheckbox[]"]').each(function(checkbox) {
            if (checkbox.checked) {
                itemsIds.push(checkbox.value);
            }
        });

        return itemsIds;
    },

    execGroupOperation: function(params) {
        var context = this;

        var ids = $H();
        var count = 0;
        this.getSelectedItemsIds().each(function(id) {
            ids.set('ids[' + count + ']', id);
            count++;
        });

        if (params.checkSelection) {
            if (!params.checkSelection()) {
                return;
            }
        } else if (0 == count) {
            this._showItemsNotSelectedWarning();
            return ;
        } else {
            this._hideItemsNotSelectedWarning();
        }

        var sendRequest = function() {
            new Ajax.Request(Jsw.prepareUrl(params.url), {
                method: 'post',
                parameters: ids,
                onSuccess: function (transport) {
                    var status = transport.responseText.evalJSON();
                    if (status.redirect) {
                        Jsw.redirect(status.redirect);
                    } else {
                        context.reload();
                    }
                    Jsw.clearStatusMessages();
                    $A(status.statusMessages).each(function(message) {
                        Jsw.addStatusMessage(message.status, message.content);
                    });

                    if (params.onSuccess) {
                        params.onSuccess();
                    } else {
                        context.enable();
                    }
                },

                onCreate: function() {
                    context.disable();
                },

                onFailure: function() {
                    context.enable();
                }
            });
        }

        if (params.skipConfirmation) {
            sendRequest();
        } else {
            Jsw.messageBox.show({
                type: Jsw.messageBox.TYPE_YESNO,
                buttonTitles: {
                    yes: this._locale.messageBoxButtonYes,
                    no: this._locale.messageBoxButtonNo
                },
                text: params.getConfirmOnGroupOperation
                    ? params.getConfirmOnGroupOperation()
                    : params.locale.confirmOnGroupOperation,
                subtype: params.subtype,
                onYesClick: sendRequest
            });
        }
    },

    _showItemsNotSelectedWarning: function() {
        var element = this._componentElement.down('.list-actions-msg');
        if (element) {
            element.show();
        } else {
            this._componentElement.down('.action-btns-area').insert('<span class="list-actions-msg"><span>' +
                this._locale.itemsNotSelected + '</span></span>');
        }
    },

    _hideItemsNotSelectedWarning: function() {
        var element = this._componentElement.down('.list-actions-msg');
        if (element) {
            element.hide();
        }
    },

    render: function($super) {
        $super();

        if (!this._data) {
            this.reload();
            return ;
        }

        this.redraw();
    },

    reload: function(params) {
        params = params || '';
        var context = this;

        new Ajax.Request(Jsw.prepareUrl(this._dataUrl + params), {
            method: 'get',
            onSuccess: function(transport) {
                if ('' == transport.responseText) {
                    //:INFO: sometimes happens in FF if you are go to other page during request
                    return;
                }
                var data = transport.responseText.evalJSON();
                if (context._splitListData(data)) {
                    context.redraw();
                } else {
                    context.processReloadError(data);
                }
            },

            onFailure: this._onReloadFailure.bind(this),

            onException: this._onReloadException.bind(this),

            onCreate: this._onReloadCreate.bind(this),

            onComplete: this._onReloadComplete.bind(this)
        });
    },

    _onReloadFailure: function(transport) {
        Jsw.clearStatusMessages();
        Jsw.addStatusMessage(
            'error',
            'Internal error: Cannot receive response from the server.'
        );
    },

    _onReloadException: function(transport, exception) {
        Jsw.clearStatusMessages();
        Jsw.addStatusMessage(
            'error',
            'Internal error: ' + exception + "\n" +
            transport.responseText
        );
    },

    _onReloadCreate: function(transport) {
        Jsw.clearStatusMessages();
        this.disable();
    },

    _onReloadComplete: function() {
        this.enable();
    },

    _addDisabledCheckboxesHints: function() {
        var checkboxes = this._componentElement.select('input[type="checkbox"][disabled]');

        checkboxes.each(function(checkbox) {
            new Jsw.Tooltip.Instance(checkbox.previous(), {text: this._disabledSelectHint });
        }, this);
    },

    redraw: function() {
        this._componentElement.down().replace(
            '<div id="' + this._id + '-container">' +
                this._getActionsBoxHtml() +
                this._getPathbarHtml() +
                this._getListHtml() +
            '</div>'
        );

        if (this._pager.totalItemCount > 0) {
            if (this._operations) {
                this._addOperations();
            }

            if (this._rowSelectable) {
                this._addSelectionHandlers();
            }
        }

        this._addPathbar();
        this._addSearchHandlers();

        if (this._disabledSelectHint) {
            this._addDisabledCheckboxesHints();
        }

        Jsw.Tooltip.initData(this._componentElement);
    },

    processReloadError: function(data) {
        Jsw.clearStatusMessages();
        Jsw.addStatusMessage(
            'error',
            'Internal error: unable to load list data'
        );
    }
});

Jsw.DynamicSubForm = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);
        var getDynamicContent = this._getConfigParam('getDynamicContent', null);
        if (getDynamicContent) {
            this._getDynamicContent = getDynamicContent.bind(this);
        }
        var prepareDynamicContent = this._getConfigParam('prepareDynamicContent', null);
        if (prepareDynamicContent) {
            this._prepareDynamicContent = prepareDynamicContent.bind(this);
        }
        var bindDynamicContent = this._getConfigParam('bindDynamicContent', null);
        if (bindDynamicContent) {
            this._bindDynamicContent = bindDynamicContent.bind(this);
        }
        var insertDynamicContent = this._getConfigParam('insertDynamicContent', null);
        if (insertDynamicContent) {
            this._insertDynamicContent = insertDynamicContent.bind(this);
        }
        var onUpdateDynamic = this._getConfigParam('onUpdateDynamic', null);
        if (onUpdateDynamic) {
            this._onUpdateDynamic = onUpdateDynamic.bind(this);
        }
        var onInitDynamic = this._getConfigParam('onInitDynamic', null);
        if (onInitDynamic) {
            this._onInitDynamic = onInitDynamic.bind(this);
        }
    },

    _addEvents: function($super) {
        $super();
        var dynamicElements = this._componentElement.select('.dynamicSubFormContent');
        if (0 == dynamicElements.size()) {
            var element = this._prepareDynamicContent(this._getDynamicContent());
            this._insertDynamicContent(element);
            this._bindDynamicContent(element, true);
        } else {
            dynamicElements.each(function(element, index) {
                this._bindDynamicContent(element, 0 == index);
            }, this);
        }
        this._onInitDynamic();
        this._onUpdateDynamic();
    },

    _getDynamicContent: function() {
        var dynamicElement = this._componentElement.down('.dynamicSubFormTemplate').cloneNode(true);
        dynamicElement.removeClassName('dynamicSubFormTemplate').addClassName('dynamicSubFormContent').show();
        return dynamicElement;
    },

    _prepareDynamicContent: function(content) {
        return content;
    },

    _insertDynamicContent: function(content) {
        var dynamicElements = this._componentElement.select('.dynamicSubFormContent');
        if (0 == dynamicElements.size()) {
            this._componentElement.insert({top : content});
        } else {
            dynamicElements.last().insert({after : content});
        }
    },

    _bindDynamicContent: function(content, isFirstElement) {
    },

    _onInitDynamic: function() {

    },

    _onUpdateDynamic: function() {
    },

    deleteContent: function(content) {
        content.remove();
        this._onUpdateDynamic();
    },

    addContent: function() {
        var content = this._prepareDynamicContent(this._getDynamicContent());
        this._insertDynamicContent(content);
        this._bindDynamicContent(content, false);
        this._onUpdateDynamic();
    }

});

Jsw.Cookie = {
    get: function(name) {
        var cookies = document.cookie.split("; ");
        for (var i = 0; i < cookies.length; i++) {
            var crumbs = cookies[i].split("=");
            if (name == crumbs[0]) {
               return unescape(crumbs[1]);
            }
        }
        return null;
    },

    set: function(name, value) {
        document.cookie = name + "=" + escape(value) + "; ";
    },

    setPermanent: function(name, value) {
        var date = new Date();
        date.setTime(date.getTime()+(365*24*60*60*1000));
        document.cookie = name + "=" + escape(value) + "; expires=" + date.toGMTString() + ";";
    },

    remove: function(name) {
        document.cookie = name + "=; expires=Fri, 31 Dec 1999 23:59:59 GMT;";
    }
};

Jsw.Tooltip = {
    showTimeoutStatus: true,    //show timeout
    showTimeout: 0.55,            //show timeout
    minDelta: 5,                //minimum viewport delta
    xOffsetLeft: -5,            //horisonatl offset from cursor
    xOffsetRight: 5,            //horisonatl offset from cursor
    yOffsetTop: 1,                //vertical offset from cursor
    yOffsetBottom: 13,            //vertical offset from cursor

    current: null,

    initData: function(contentElement) {
        var elements;

        if ('undefined' != typeof contentElement) {
            elements = contentElement.select('.tooltipData');
        } else {
            elements = $$('.tooltipData');
        }

        elements.each(function(tooltipData) {
            Jsw.Tooltip.init(tooltipData.parentNode, {element: tooltipData});
        });
    },

    init: function(element, config) {
        return new Jsw.Tooltip.Instance(element, config);
    },

    set: function(tooltip) {
        if (Jsw.Tooltip.current && Jsw.Tooltip.current !== tooltip) {
            Jsw.Tooltip.hide();
        }
        if (Jsw.Tooltip.current === tooltip) {
            return;
        }
        Jsw.Tooltip.current = tooltip;
        Element.observe(tooltip._element, 'mousemove', Jsw.Tooltip._onMouseMove);
        Element.observe(tooltip._element, 'mouseout', Jsw.Tooltip._onMouseOut);

        Jsw.Tooltip.show();
    },

    show: function() {
        Jsw.Tooltip.showCancel();
        Jsw.Tooltip.hideCancel();
        if (Jsw.Tooltip.showTimeoutStatus) {
            Jsw.Tooltip.showTask = new PeriodicalExecuter(Jsw.Tooltip.showFinish, Jsw.Tooltip.showTimeout);
        } else {
            Jsw.Tooltip.showFinish();
        }
    },

    showCancel: function() {
        if (Jsw.Tooltip.showTask) {
            Jsw.Tooltip.showTask.stop();
            Jsw.Tooltip.showTask = null;
        }
    },

    showFinish: function() {
        Jsw.Tooltip.showCancel();
        var tooltipElement = Jsw.Tooltip._fetchTooltipElement();
        var tooltip = Jsw.Tooltip.current;
        if (tooltip._config.text) {
            tooltipElement.down('span').update(tooltip._config.text);
        } else
        if(tooltip._config.element) {
            tooltipElement.down('span').update(tooltip._config.element.innerHTML);
        }
        tooltipElement.show();
        Jsw.Tooltip.update();
    },

    hide: function() {
        Jsw.Tooltip.showCancel();
        if (!Jsw.Tooltip.current)
            return;
        var tooltip = Jsw.Tooltip.current;
        Jsw.Tooltip.current = null;
        var tooltipElement = Jsw.Tooltip._fetchTooltipElement();
        tooltipElement.hide();
        Element.stopObserving(tooltip._element, 'mousemove', Jsw.Tooltip._onMouseMove);
        Element.stopObserving(tooltip._element, 'mouseout', Jsw.Tooltip._onMouseOut);
        Jsw.Tooltip.hideTask = new PeriodicalExecuter(Jsw.Tooltip.hideFinish, Jsw.Tooltip.showTimeout);
    },

    hideCancel: function() {
        if (Jsw.Tooltip.hideTask) {
            Jsw.Tooltip.hideTask.stop();
            Jsw.Tooltip.hideTask = null;
        }
    },

    hideFinish: function() {
        Jsw.Tooltip.showTimeoutStatus = true;
    },

    update: function() {
        if (!Jsw.Tooltip.current)
            return;
        var tooltipElement = Jsw.Tooltip._fetchTooltipElement();
        var position = Jsw.Tooltip._fetchTooltipPosition(tooltipElement);
        Element.setStyle(tooltipElement, {
            top: position.y + 'px',
            left: position.x + 'px'
        });
    },

    _onMouseOut: function(event) {
        Jsw.Tooltip.hide();
    },

    _onMouseMove: function(event) {
        Jsw.Tooltip.tooltipX = Event.pointerX(event);
        Jsw.Tooltip.tooltipY = Event.pointerY(event);
        Jsw.Tooltip.update();
    },

    _fetchTooltipElement: function() {
        if (!Jsw.Tooltip._tooltipElement) {
            Jsw.Tooltip._tooltipElement = $$('.tooltip').first();
        }

        return Jsw.Tooltip._tooltipElement;
    },

    _fetchTooltipPosition: function(tooltipElement) {
        var x = Jsw.Tooltip.tooltipX;
        var y = Jsw.Tooltip.tooltipY;

        var tDim = Element.getDimensions(tooltipElement);
        var vDim = document.viewport.getDimensions();
        var vScr = document.viewport.getScrollOffsets();

        var freeRight = vDim.width + vScr.left - Jsw.Tooltip.tooltipX;
        var freeLeft = Jsw.Tooltip.tooltipX - vScr.left;
        var freeTop = Jsw.Tooltip.tooltipY - vScr.top;
        var freeBottom = vDim.height + vScr.top - Jsw.Tooltip.tooltipY;

        //apply better x
        if( freeRight > tDim.width + Jsw.Tooltip.minDelta + Jsw.Tooltip.xOffsetRight) {
            x = Jsw.Tooltip.tooltipX + Jsw.Tooltip.xOffsetRight;
        } else
        if( freeLeft > tDim.width + Jsw.Tooltip.minDelta + Jsw.Tooltip.xOffsetLeft) {
            x = Jsw.Tooltip.tooltipX - tDim.width - Jsw.Tooltip.xOffsetLeft;
        } else {
            x = Jsw.Tooltip.tooltipX - (tDim.width + Jsw.Tooltip.xOffsetLeft) / 2;
        }

        //apply better y
        if (freeBottom > tDim.height + Jsw.Tooltip.minDelta + Jsw.Tooltip.yOffsetBottom) {
            y = Jsw.Tooltip.tooltipY + Jsw.Tooltip.yOffsetBottom;
        } else
        if( freeTop > tDim.height + Jsw.Tooltip.minDelta + Jsw.Tooltip.yOffsetTop) {
            y = Jsw.Tooltip.tooltipY - tDim.height - Jsw.Tooltip.yOffsetTop;
        } else {
            y = Jsw.Tooltip.tooltipY - (tDim.height + Jsw.Tooltip.yOffsetTop) / 2;
        }

        return { x: x, y: y };
    }

}

Event.observe(window, 'load', function() {
    Jsw.Tooltip.initData();
});

Jsw.Tooltip.Instance = Class.create({

    initialize: function(element, config) {
        this._element = element;
        this._config = config;
        //observe events
        Event.observe(this._element, 'mouseover', this.set.bind(this));
    },

    set: function() {
        Jsw.Tooltip.set(this);
    },

    setText: function(text) {
        this._config.text = text;
    }
});

Jsw.messageBox = {

    TYPE_OK: 'TYPE_OK',
    TYPE_YESNO: 'TYPE_YESNO',

    _messageBox: null,

    show: function(config) {
        if (!self._messageBox) {
            self._messageBox = new Jsw.MessageBox(config);
        } else {
            self._messageBox.initialize(config);
        }

        self._messageBox.show();
    }
}

Jsw.ModalDialogBox = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);

        this._screenDisablerId = this._getConfigParam('screenDisablerId', 'screenDisabler');

        if (!$(this._screenDisablerId)) {
            $(document.body).insert({
                top: '<div id="' + this._screenDisablerId + '" class="main-disabled-block" style="display: none;"></div>'
            });
        }

        this._screenDisabler = $(this._screenDisablerId);

        this._renderTargetId = this._getConfigParam('renderTo', 'modalDialogBox');

        if ($(this._renderTargetId)) {
            $(this._renderTargetId).remove();
        }

        this._screenDisabler.insert({ after: '<div id="' + this._renderTargetId + '"></div>' });
    },

    show: function($super) {
        this._screenDisabler.show();

        $super();
    },

    hide: function($super) {
        $super();

        this._screenDisabler.hide();
    }

});

Jsw.MessageBox = Class.create(Jsw.ModalDialogBox, {

    _initConfiguration: function($super, config) {
        $super(config);

        this._type = this._getConfigParam('type', Jsw.messageBox.TYPE_YESNO);
        this._text = this._getConfigParam('text', '');
        this._subtype = this._getConfigParam('subtype', null);
        this._description = this._getConfigParam('description', '');
        this._buttonTitles = this._getConfigParam('buttonTitles', null);

        this._onYesClick = this._getConfigParam('onYesClick', null);
        this._onNoClick = this._getConfigParam('onNoClick', null);
        this._onOkClick = this._getConfigParam('onOkClick', null);
    },

    _initComponentElement: function($super) {
        $super();

        var descriptionCode = '';
        if (Object.isArray(this._description)) {
            this._description.each(function(item) {
                descriptionCode += '<p>' + item + '</p>';
            })
        } else {
            descriptionCode += '<p>' + this._description + '</p>';
        }

        var contentHtml =
            '<div class="confirmation-box">' +
                '<table cellspacing="0"><tr><td>' +
                    '<div class="c1"><div class="c2"><div class="c3"><div class="c4"><div class="c5">' +
                        '<div class="confirmation-msg' + (this._subtype ? ' mw-' + this._subtype : '') + '">' +
                            '<h3>' + this._text + '</h3>' +
                            descriptionCode +
                            '<div class="btns-container">';

        if (Jsw.messageBox.TYPE_YESNO == this._type) {
            var buttonDefault = this._getConfigParam('buttonDefault', 'no');
            contentHtml += '<span class="btn' + ('yes' == buttonDefault ? ' action' : '') + '"><button type="submit" value="">' + this._buttonTitles.yes + '</button></span>';
            contentHtml += '<span class="btn' + ('no' == buttonDefault ? ' action' : '') + '"><button type="submit" value="">' + this._buttonTitles.no + '</button></span>';
        }

        if (Jsw.messageBox.TYPE_OK == this._type) {
            contentHtml += '<span class="btn action"><button type="submit" value="">' + this._buttonTitles.ok + '</button></span>';
        }

        contentHtml +=      '</div>' +
                        '</div>' +
                    '</div></div></div></div></div>' +
                '</td><tr></table>' +
            '</div>';

        this._updateComponentElement(contentHtml);

        this._componentElement.hide();
    },

    _addEvents: function($super) {
        $super();

        // add default behavior - hide dialog
        this._componentElement.select('button').each(function(button) {
            Event.observe(button, 'click', this._defaultOnButtonClick.bindAsEventListener(this));
        }, this);

        if (Jsw.messageBox.TYPE_YESNO == this._type) {
            if (this._onYesClick) {
                var buttonYes = this._componentElement.select('button').first();
                Event.observe(buttonYes, 'click', this._onYesClick.bindAsEventListener(this));
            }

            if (this._onNoClick) {
                var buttonNo = this._componentElement.select('button').last();
                Event.observe(buttonNo, 'click', this._onNoClick.bindAsEventListener(this));
            }
        }

        if (Jsw.messageBox.TYPE_OK == this._type) {
            if (this._onOkClick) {
                var buttonOk = this._componentElement.select('button').first();
                Event.observe(buttonOk, 'click', this._onOkClick.bindAsEventListener(this));
            }
        }
    },

    _addTooltips: function() {
    },

    _defaultOnButtonClick: function() {
        this.hide();
    },

    show: function($super) {
        $super();
        this._componentElement.select('.action').first().select('button').first().focus();
    }

});

Jsw.DoubleListSelector = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._cls = 'doubleListSelect';
        this._name = this._getConfigParam('name', '');
        this._initList();
        this._selectedMarked = 0;
        this._unselectedMarked = 0;
    },

    _initList: function() {
        this._list = this._getConfigParam('list', $A());
        this._list.each(function(element) {
            element.marked = false;
        });
    },

    _initComponentElement: function($super) {
        $super();
        var listHtml =
            '<div class="dls-first-box">' +
                '<h4><span>' + this._getConfigParam('unselectedTitle', '') + '</span></h4>' +
                '<div class="dls-box-area"><ul id="' + this._id + '-unselected"></ul></div>' +
            '</div>' +
            '<div class="dls-second-box">' +
                '<h4><span>' + this._getConfigParam('selectedTitle', '') +'</span></h4>' +
                '<div class="dls-box-area"><ul id="' + this._id + '-selected"></ul></div>' +
            '</div>' +
            '<div id="' + this._id + '-controls" class="dls-controls">' +
                '<span id="' + this._id + '-controls-select" class="btn disabled">' +
                    '<button id="'+ this._id +'-submitSelect" onclick="return false;"><span class="dls-add">&gt;&gt;</span></button>' +
                '</span>' +
                '<span id="' + this._id + '-controls-unselect" class="btn disabled">' +
                    '<button id="'+ this._id +'-submitUnselect" onclick="return false;"><span class="dls-remove">&lt;&lt;</span></button>' +
                '</span>' +
            '</div>';

        this._updateComponentElement(listHtml);

        this._list.each(function(element, index) {
            this._initListItem(element, index, true);
            this._initListItem(element, index, false);
            this._initInputElement(element, index);
        }, this);
    },

    _initListItem: function(element, index, isSelected) {
        var container = null;
        var isHidden = false;
        if (isSelected) {
            container = $(this._id + '-selected');
            isHidden = !element.selected;
        } else {
            container = $(this._id + '-unselected');
            isHidden = element.selected;
        }

        var listItem = new Element('li', {
            'id': this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item'
        })
        .insert('<b>' + element.title + '</b>')
        .insert('<span>' + element.description + '</span>');

        container.insert(listItem);
        var context = this;
        listItem.observe('click', function() {
            context._toggleItem(index, isSelected);
        });
        if (isHidden) {
            listItem.hide();
        }
    },

    _initInputElement: function(element) {
        this._componentElement.insert(new Element('input', {
            'id': this._id + '-' + element.id,
            'name': this._name + '[' + element.id + ']',
            'type': 'hidden',
            'value': (element.selected ? 'true' : 'false')
        }));
    },

    _addEvents: function() {
        $(this._id + '-controls-select').observe('click', this._onSubmitSelect.bind(this));
        $(this._id + '-controls-unselect').observe('click', this._onSubmitUnselect.bind(this));
    },

    _toggleItem: function(index, isSelected) {
        if (this._list[index].marked) {
            this._unmarkItem(index, isSelected);
        } else {
            this._markItem(index, isSelected);
        }
    },

    _markItem: function(index, isSelected) {
        this._list[index].marked = true;
        $(this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item').addClassName('marked');
        if (isSelected) {
            this._selectedMarked++;
            $(this._id + '-controls-unselect').removeClassName('disabled');
        } else {
            this._unselectedMarked++;
            $(this._id + '-controls-select').removeClassName('disabled');
        }
    },

    _unmarkItem: function(index, isSelected) {
        this._list[index].marked = false;
        $(this._id + '-' + index + '-' + (isSelected ? 'selected' : 'unselected') + '-item').removeClassName('marked');
        if (isSelected) {
            this._selectedMarked--;
            if (0 == this._selectedMarked) {
                $(this._id + '-controls-unselect').addClassName('disabled');
            }
        } else {
            this._unselectedMarked--;
            if (0 == this._unselectedMarked) {
                $(this._id + '-controls-select').addClassName('disabled');
            }
        }
    },

    _onSubmitSelect: function() {
        this._list.each(function(element, index) {
            if (element.marked && !element.selected) {
                this._unmarkItem(index, false);
                element.selected = true;
                $(this._id + '-' + element.id).value = 'true';
                $(this._id + '-' + index + '-unselected-item').hide();
                $(this._id + '-' + index + '-selected-item').show();
            }
        }, this);
    },

    _onSubmitUnselect: function() {
        this._list.each(function(element, index) {
            if (element.marked && element.selected) {
                this._unmarkItem(index, true);
                element.selected = false;
                $(this._id + '-' + element.id).value = 'false';
                $(this._id + '-' + index + '-selected-item').hide();
                $(this._id + '-' + index + '-unselected-item').show();
            }
        }, this);
    }
});

Jsw.ImageSelector = Class.create(Jsw.Component, {
    _initConfiguration: function($super, config) {
        $super(config);
        var list = this._getConfigParam('list', {});
        this._list = Object.isArray(list) ? $H() : $H(list);
        var captions = this._getConfigParam('captions', {});
        this._captions = Object.isArray(captions) ? $H() : $H(captions);
        this._name = this._getConfigParam('name', '');
        this._value = this._getConfigParam('value', null);

        this._currentId = this._id + '-current';
        this._listId = this._id + '-list';
    },

    _initComponentElement: function($super) {
        $super();

        this._updateComponentElement(
            '<div class="' + this._cls + '-area">' +
                '<div id="' + this._currentId + '" class="' + this._cls + '-current">' +
                    '<img/>' +
                    '<p>' + this._captions.get('selectedImage').escapeHTML() + '</p>' +
                '</div>' +
                '<div id="' + this._listId + '" class="' + this._cls + '-select clearfix"></div>' +
            '</div>'
        );

        this._valueElement = new Element('input', {
            'id': this._id + '-value',
            'name': this._name,
            'type': 'hidden',
            'value': null
        });

        this._componentElement.insert(this._valueElement);
    },

    _addEvents: function() {
        this._list.each(function(pair) {
            this._addImage(pair.key, pair.value);
        }, this);

        this.set(this._value);
    },

    _addImage: function(value, image) {
        this._componentElement.select('#' + this._listId).each(function(target) {
            var element = new Element('img', {
                'src': image.url,
                'alt': image.title
            });

            target.insert(element);

            element.observe('click', this._onImageClick.bindAsEventListener(this, value));
        }, this);
    },

    _onImageClick: function(event, value)
    {
        this.set(value);
    },

    set: function(value)
    {
        this._valueElement.value = value;
        var image = this._list.get(value);
        this._componentElement.select('#' + this._currentId + ' img').each(function(target) {
            if (image) {
                target.src = image.url;
                target.alt = image.title;
                target.show();
            } else {
                target.hide();
            }
        }, this);

    }

});

Object.extend(Form.Element.Methods, {
    disable: function(element) {
        element = $(element);
        element.disabled = 'disabled';
        element.addClassName('disabled');
        return element;
    },

    enable: function(element) {
        element = $(element);
        element.disabled = false;
        element.removeClassName('disabled');
        return element;
    }
});

Element.addMethods();
