/* SMB specific JavaScript classes */

Jsw.namespace('Smb');

Smb.DynamicSubForm = Class.create(Jsw.DynamicSubForm, {
    _initConfiguration: function($super, config) {
        $super(config);
        this._addButtonId = this._getConfigParam('addButtonId', '');
        this._addButtonTitle = this._getConfigParam('addButtonTitle', '');
        this._removeButtonId = this._getConfigParam('removeButtonId', '');
        this._removeButtonTitle = this._getConfigParam('removeButtonTitle', '');
    },

    _onInitDynamic: function() {
        $(this._addButtonId).replace('<div id="' + this._addButtonId + '" class="text-value"></div>');
        new Jsw.SmallButton({
            id: 'dynamicSubFormContentAddButton-' + this._id,
            title: this._addButtonTitle,
            addCls: 'sb-item-add dynamicSubFormContentAddButton',
            handler: this.addContent.bind(this),
            disabled: this._isAddButtonDisabled(),
            renderTo: this._addButtonId
        });
    },

    _isAddButtonDisabled: function() {
        return false;
    },

    _bindDynamicContent: function(content, isFirstElement) {
        if (!isFirstElement) {
            var wrapperId = this._initRemoveButtonWrapper(content);
            new Jsw.SmallButton({
                id: wrapperId,
                title: this._removeButtonTitle,
                addCls: 'sb-item-remove dynamicSubFormContentRemoveButton',
                handler: this.deleteContent.bind(this, content),
                renderTo: wrapperId
            });
        }
        return content;
    },

    _initRemoveButtonWrapper: function(content) {
        var wrapperId = this._removeButtonId + '-' + this._getRandomNumber();
        content.select('.field-value input').last().insert({
            after: '<span id="' + wrapperId + '" class="' + this._removeButtonId + '"></span>'
        });
        return wrapperId;
    },

    _prepareDynamicContent : function(content) {
        var newId = Math.floor(1000000*Math.random());

        var nameRegExp = new RegExp("(name=.*\\[" + this._id + "\\]\\[)dynamicSubFormTemplate(\\])", "g");
        var idRegExp = new RegExp("(id=.*\\-" + this._id + "-)dynamicSubFormTemplate(-)", "g");

        content = content.update(content.innerHTML
            .replace(nameRegExp, '\$1c' + newId +'\$2')
            .replace(idRegExp, '\$1c' + newId +'\$2')
        );

        return content;
    },

    _onUpdateDynamic: function() {
        var childs = this._componentElement.select('.dynamicSubFormContent');
        if (0 < childs.size()) {
            childs.each(function(child, i) {
                if (0 == i) {
                    child.select('label').last().show();
                } else {
                    child.select('label').last().hide();
                }
            });
            $$('label[for="' + this._addButtonId + '"]').first().hide();
        } else {
            $$('label[for="' + this._addButtonId + '"]').first().show();
        }
    },

    addContent: function($super, event) {
        $super();
        event.stop();
    },

    deleteContent: function($super, content, event) {
        $super(content);
        event.stop();
    }
});

Smb.Webmail = {

    urlWrapper: function(webmailUrl) {
        var wrapper = 'window.open("' + webmailUrl + '", "webmail", ' +
            '"width=700,height=600,innerWidth=700,innerHeight=600,toolbar=yes,personalbar=no,' +
            'locationbar=no,statusbar=no,scrollbars=yes,resizable=yes");';

        return wrapper;
    }

}

Smb.ApsLicense = {

    buy: function(action, body) {
        var form = new Element('form');
        var input = new Element('input');

        form.hide();
        form.action = action;
        form.target = '_blank';
        form.method = 'post';
        form.enctype = 'application/x-www-form-urlencoded';

        input.type = 'hidden';
        input.name = 'data';
        input.value = body;

        form.insert(input);
        $(document.body).insert(form);
        form.submit();
    },

    initForm: function() {
        Event.observe($('apsLicense-provider-parallels'), 'click', this.onChangeVendor);
        Event.observe($('apsLicense-provider-vendor'), 'click', this.onChangeVendor);
        Event.observe($('apsLicense-uploadType-text'), 'click', this.onChangeUploadType);
        Event.observe($('apsLicense-uploadType-file'), 'click', this.onChangeUploadType);

        this.onChangeVendor();
        this.onChangeUploadType();
    },

    onChangeUploadType: function() {
        if ($('apsLicense-uploadType-text').checked) {
            $('apsLicense-uploadText').enable();
            $('apsLicense-uploadFile').disable();
        } else {
            $('apsLicense-uploadText').disable();
            $('apsLicense-uploadFile').enable();
        }
    },

    onChangeVendor: function() {
        if ($('apsLicense-provider-parallels').checked) {
            $('apsLicense-uploadTextRadio-form-row').hide();
            $('apsLicense-uploadFileRadio-form-row').hide();
            $('apsLicense-license-form-row').show();
        } else {
            $('apsLicense-uploadTextRadio-form-row').show();
            $('apsLicense-uploadFileRadio-form-row').show();
            $('apsLicense-license-form-row').hide();
        }
    }
};

Smb.GettingStartedPopup = Class.create({

    initialize: function(containerId) {
        this._container = $(containerId);

        if (!this._container) {
            return;
        }

        this._container.select('.getting-started-link').each((
            function(element) {
                element.observe('click', this._onOkClick.bindAsEventListener(this));
            }
        ).bind(this));
        this._container.select('.s-btn.action').each((
            function(element) {
                element.observe('click', this._onOkClick.bindAsEventListener(this));
            }
        ).bind(this));
        this._container.select('.s-btn').each((
            function(element) {
                if (element.hasClassName('action')) {
                    return;
                }
                element.observe('click', this._onCancelClick.bindAsEventListener(this));
            }
        ).bind(this));

        if ('true' != Jsw.Cookie.get('show-getting-started-popup')) {
            return;
        }
        if ('true' == Jsw.Cookie.get('do-not-show-getting-started-popup')) {
            return;
        }

        this._container.addClassName('active');
        $(document.body).insert({
            top: '<div class="main-disabled-block"></div>'
        });
    },

    _onOkClick: function(event) {
        Event.stop(event);

        this._processNotShow();
        this._openGuide();
        this._close();
    },

    _onCancelClick: function(event) {
        Event.stop(event);

        this._processNotShow();
        this._close();
    },

    _openGuide: function() {
        window.open(
            Jsw.baseUrl +
            '/help/redirect/controller-name/quick-start' +
            '/action-name/index'
        );

    },

    _close: function() {
        this._container.removeClassName('active');

        $(document.body).select('.main-disabled-block').each(
            function(element) {
                element.remove();
            }
        );
        Jsw.Cookie.set('show-getting-started-popup', 'false');
    },

    _processNotShow: function() {
        var checkbox = this._container.select('input').first();
        if (checkbox.checked) {
            Jsw.Cookie.setPermanent(
                'do-not-show-getting-started-popup',
                'true'
            );
        }
    }
});

Smb.NavigationTabs = Class.create(Jsw.bar.Tabs, {
    _renderItems: function($super) {
        $super();
        var contentAreaWidth = $(this._contentAreaId).getWidth();
        var items = $(this._contentAreaId).childElements();
        var itemsWidth = 0;

        items.each(function(item) {
            itemsWidth += item.getWidth() + 1;
        });

        if (itemsWidth > contentAreaWidth) {
            var delta = Math.ceil((itemsWidth - contentAreaWidth) / items.size());
            var paddingDelta = Math.ceil(delta / 2);

            var leftPadding = 10 - paddingDelta;
            if (leftPadding < 0) {
                leftPadding = 0;
            }

            var rightPadding = 15 - paddingDelta;
            if (rightPadding < 5) {
                rightPadding = 5;
            }

            items.each(function(item) {
                item.down('span').setStyle({
                    padding: '0 ' + rightPadding + 'px 0 ' + leftPadding + 'px'
                })
            });
        }
    }
});

//prevent AJAX request canceling on Escape button press in Firefox
$(document).observe('keydown', function(event) {
    if (Event.KEY_ESC == event.keyCode) {
        Event.stop(event);
    }
});

Jsw.namespace('Smb.UserPack');

Smb.UserPack.Promotion = Class.create(Jsw.Component, {

    _initConfiguration: function($super, config) {
        $super(config);
        this._locale = this._getConfigParam('locale', {});
        this._buyUserPackLinkId = this._id + '-buy-userpack-link';
    },

    _initComponentElement: function($super) {
        $super();
        var gaugeClass = '';
        var value = this._getConfigParam('value', 0);
        if (100 <= value) {
            gaugeClass = 'over';
        } else if (0 < value) {
            gaugeClass = 'not_empty';
        }
        this._updateComponentElement(
            '<div class="info-box">' +
                '<table cellspacing="0"><tbody><tr><td>' +
                    '<div class="info-box-data">' +
                        this._locale.header +
                    '</div>' +
                    '<span title="" class="gauge-wrapper f5 ' + gaugeClass + '">' +
                        '<span class="gauge-container">' +
                            '<span style="width: ' +
                                (100 >= value ? value : 100) +
                                '%;" class="gauge-filled">' +
                            '</span>' +
                        '</span>' +
                    '</span>' +
                    '<div class="info-box-link">' +
                        '<a href="#" id="' + this._buyUserPackLinkId + '">' +
                            this._locale.link +
                        '</a>' +
                    '</div>' +
                '</td></tr></tbody></table>' +
            '</div>'
        );
    },

    _addEvents: function($super) {
        $super();
        $(this._buyUserPackLinkId).observe('click', this._onBuyUserPackClick.bindAsEventListener(this));
    },

    _onBuyUserPackClick: function(event) {
            Event.stop(event);
            Jsw.redirectPost(this._getConfigParam('buyUserPackUrl'), {
                    data: this._getConfigParam('buyUserPackData')
            }, '_blank');
    }

});